@@ -9,7 +9,8 @@
 #include <stddef.h>
 #include <math.h>
 
-#if (_XOPEN_SOURCE >= 600) || (__STDC_VERSION__ >= 199901L)
+#if ( defined(_XOPEN_SOURCE) && (_XOPEN_SOURCE >= 600)) \
+   || (__STDC_VERSION__ >= 199901L)
 /*
  * Supply GCCisms that stop being visible if we tell it we need the
  * prototype for strptime(3).  Note that this conditionalization is
@@ -22,13 +23,12 @@ typedef unsigned short	u_short;
 typedef unsigned int	u_int;
 #endif
 
-#include <ntp_fp.h>
-#include <ntp_types.h>
-#include <ntp_lists.h>
-#include <ntp_stdlib.h>
-#include <ntp_crypto.h>
-#include <ntp_random.h>
-#include <ntp_net.h>
+#include "ntp_fp.h"
+#include "ntp_types.h"
+#include "ntp_lists.h"
+#include "ntp_stdlib.h"
+#include "ntp_random.h"
+#include "ntp_net.h"
 
 /*
  * Calendar arithmetic - contributed by G. Healton
@@ -48,28 +48,12 @@ typedef unsigned int	u_int;
 			    / 4 - ((year - 1) / 100) + ((year - 1) / \
 			    400)) : 0))
 
-/*
- * Number of days since start of NTP time to 1 January of given year
- */
-#define ntp0(year)	(julian0(year) - julian0(1900))
-
-/*
- * Number of days since start of UNIX time to 1 January of given year
- */
-#define unix0(year)	(julian0(year) - julian0(1970))
-
 /*
  * LEAP YEAR test for full 4-digit years (e.g, 1999, 2010)
  */
 #define isleap_4(y)	((y) % 4 == 0 && !((y) % 100 == 0 && !(y % \
 			    400 == 0)))
 
-/*
- * LEAP YEAR test for tm_year (struct tm) years (e.g, 99, 110)
- */
-#define isleap_tm(y)	((y) % 4 == 0 && !((y) % 100 == 0 && !(((y) \
-			    + 1900) % 400 == 0)))
-
 /*
  * to convert simple two-digit years to tm_year style years:
  *
@@ -109,36 +93,24 @@ typedef unsigned int	u_int;
 #define	NTP_MINPKT	2	/* guard time (s) */
 
 /*
- * Clock filter algorithm tuning parameters
+ * Clock filter algorithm tuning parameter
  */
-#define MAXDISPERSE	16.	/* max dispersion */
 #define	NTP_SHIFT	8	/* clock filter stages */
-#define NTP_FWEIGHT	.5	/* clock filter weight */
 
 /*
  * Selection algorithm tuning parameters
  */
-#define	NTP_MINCLOCK	3	/* min survivors */
-#define	NTP_MAXCLOCK	10	/* max candidates */
-#define MINDISPERSE	.001	/* min distance */
 #define MAXDISTANCE	1.5	/* max root distance (select threshold) */
-#define CLOCK_SGATE	3.	/* popcorn spike gate */
 #define HUFFPUFF	900	/* huff-n'-puff sample interval (s) */
-#define MAXHOP		2	/* anti-clockhop threshold */
-#define MAX_TTL		8	/* max ttl mapping vector size */
-#define NTP_MAXEXTEN	2048	/* max extension field size */
-#define	NTP_ORPHWAIT	300	/* orphan wair (s) */
 
 /*
  * Miscellaneous stuff
  */
 #define NTP_MAXKEY	65535	/* max authentication key number */
-#define	KEY_TYPE_MD5	NID_md5	/* MD5 digest NID */
 /*
  * Limits of things
  */
 #define	MAXFILENAME	256	/* max length of file name */
-#define MAXHOSTNAME	512	/* max length of host/node name */
 #define NTP_MAXSTRLEN	256	/* max string length */
 
 /*
@@ -154,9 +126,7 @@ typedef unsigned int	u_int;
  */
 #define SQUARE(x) ((x) * (x))
 #define SQRT(x) (sqrt(x))
-#define DIFF(x, y) (SQUARE((x) - (y)))
 #define LOGTOD(a)	ldexp(1., (int)(a)) /* log2 to double */
-#define UNIVAR(x)	(SQUARE(.28867513 * LOGTOD(x))) /* std uniform distr */
 #define ULOGTOD(a)	ldexp(1., (int)(a)) /* ulog2 to double */
 
 #define	EVENT_TIMEOUT	0	/* one second, that is */
@@ -249,6 +219,11 @@ typedef struct __endpt {
  * The peer structure. Holds state information relating to the guys
  * we are peering with. Most of this stuff is from section 3.2 of the
  * spec.
+ *
+ * The ttl field is overloaded; it's used in the refclock case to pass
+ * in a mode byte that may contain a baud rate or subtype. Splitting
+ * this fields would complicate some call sequences that are already
+ * unpleasantly intricate.
  */
 struct peer {
 	struct peer *p_link;	/* link pointer in free & peer lists */
@@ -270,7 +245,7 @@ struct peer {
 	uint8_t	cast_flags;	/* additional flags */
 	uint8_t	last_event;	/* last peer error code */
 	uint8_t	num_events;	/* number of error events */
-	uint32_t	ttl;	/* ttl/refclock mode */
+	uint32_t ttl;		/* time-to-live/refclock mode */
 
 	/*
 	 * Variables used by reference clock support
@@ -431,17 +406,6 @@ struct peer {
 #define	FLAG_TRUE	0x0400	/* force truechimer */
 #define FLAG_TSTAMP_PPS	0x4cd000	/* PPS source provides absolute timestamp */
 
-/*
- * Definitions for the clear() routine.  We use memset() to clear
- * the parts of the peer structure which go to zero.  These are
- * used to calculate the start address and length of the area.
- */
-#define	CLEAR_TO_ZERO(p)	((char *)&((p)->clear_to_zero))
-#define	END_CLEAR_TO_ZERO(p)	((char *)&((p)->end_clear_to_zero))
-#define	LEN_CLEAR_TO_ZERO(p)	(END_CLEAR_TO_ZERO(p) - CLEAR_TO_ZERO(p))
-#define CRYPTO_TO_ZERO(p)	((char *)&((p)->clear_to_zero))
-#define END_CRYPTO_TO_ZERO(p)	((char *)&((p)->end_clear_to_zero))
-#define LEN_CRYPTO_TO_ZERO	(END_CRYPTO_TO_ZERO((struct peer *)0) \
 
 /*
  * It's ugly that refid is sometimes treated as a  uint32_t and sometimes
@@ -494,10 +458,10 @@ struct pkt {
 	u_fp	rootdelay;	/* roundtrip delay to primary source */
 	u_fp	rootdisp;	/* dispersion to primary source*/
 	uint32_t	refid;		/* reference id */
-	l_fp	reftime;	/* last update time */
-	l_fp	org;		/* originate time stamp */
-	l_fp	rec;		/* receive time stamp */
-	l_fp	xmt;		/* transmit time stamp */
+	l_fp_w	reftime;	/* last update time */
+	l_fp_w	org;		/* originate time stamp */
+	l_fp_w	rec;		/* receive time stamp */
+	l_fp_w	xmt;		/* transmit time stamp */
 
 #define MIN_MAC_LEN	(1 * sizeof(uint32_t))	/* crypto_NAK */
 #define MAX_MD5_LEN	(5 * sizeof(uint32_t))	/* MD5 */
@@ -522,19 +486,6 @@ struct pkt {
 #define VN_MODE(v, m)		((((v) & 7) << 3) | ((m) & 0x7))
 #define	PKT_LI_VN_MODE(l, v, m) ((((l) & 3) << 6) | VN_MODE((v), (m)))
 
-
-/* pythonize-header: start ignoring */
-/*
- * Dealing with stratum.  0 gets mapped to 16 incoming, and back to 0
- * on output.
- */
-#define	PKT_TO_STRATUM(s)	((uint8_t)(((s) == (STRATUM_PKT_UNSPEC)) ?\
-				(STRATUM_UNSPEC) : (s)))
-
-#define	STRATUM_TO_PKT(s)	((uint8_t)(((s) == (STRATUM_UNSPEC)) ?\
-				(STRATUM_PKT_UNSPEC) : (s)))
-
-/* pythonize-header: stop ignoring */
 /*
  * Event codes. Used for reporting errors/events to the control module
  */
@@ -601,12 +552,11 @@ struct pkt {
 #define	NTP_HASH_ADDR(src)	(sock_hash(src) & NTP_HASH_MASK)
 
 /*
- * min, min3 and max.  Makes it easier to transliterate the spec without
+ * min, and max.  Makes it easier to transliterate the spec without
  * thinking about it.
  */
 #define	min(a,b)	(((a) < (b)) ? (a) : (b))
 #define	max(a,b)	(((a) > (b)) ? (a) : (b))
-#define	min3(a,b,c)	min(min((a),(b)), (c))
 
 
 /*
@@ -630,7 +580,7 @@ struct pkt {
 #define PROTO_MINSANE		16
 #define PROTO_FLOOR		17
 #define PROTO_CEILING		18
-#define PROTO_COHORT		19
+/* #define PROTO_COHORT		19 */
 #define PROTO_CALLDELAY		20
 #define PROTO_MINDISP		21
 #define PROTO_MAXDIST		22
@@ -667,8 +617,6 @@ struct pkt {
 #define	STATS_PID_FILE		3	/* configure ntpd PID file */
 #define	STATS_LEAP_FILE		4	/* configure ntpd leapseconds file */
 
-#define MJD_1900		15020	/* MJD for 1 Jan 1900 */
-
 /*
  * Default parameters.  We use these in the absence of something better.
  * (Historical relic - muliticast mode has been removed for security reasons.)
