@@ -50,7 +50,6 @@
 
 /* ntp_config.c */
 #define	TAI_1972	10	/* initial TAI offset (s) */
-extern	char	*keysdir;	/* crypto keys and leaptable directory */
 
 extern	const char	*getconfig	(const char *);
 extern	void	readconfig(const char *);
@@ -101,6 +100,7 @@ typedef struct interface_info {
 
 typedef void	(*interface_receiver_t)	(void *, interface_info_t *);
 
+extern  bool listen_to_virtual_ips;
 extern	void	interface_enumerate	(interface_receiver_t, void *);
 extern	endpt *	getinterface		(sockaddr_u *, uint32_t);
 extern	endpt *	select_peerinterface	(struct peer *, sockaddr_u *,
@@ -114,7 +114,7 @@ extern	void	init_io 	(void);
 extern  SOCKET	open_socket	(sockaddr_u *, bool, bool, endpt *);
 extern	void	io_open_sockets	(void);
 extern	void	io_clr_stats	(void);
-extern	void	sendpkt 	(sockaddr_u *, endpt *, int, void *, int);
+extern	void	sendpkt 	(sockaddr_u *, endpt *, void *, int);
 #ifdef DEBUG
 extern	void	collect_timing  (struct recvbuf *, const char *, int, l_fp *);
 #endif
@@ -146,7 +146,7 @@ extern  int	mon_get_oldest_age(l_fp);
 /* ntp_peer.c */
 extern	void	init_peer	(void);
 extern	struct peer *findexistingpeer(sockaddr_u *, const char *,
-				      struct peer *, int, uint8_t);
+				      struct peer *, int);
 extern	struct peer *findpeer	(struct recvbuf *, int, int *);
 extern	struct peer *findpeerbyassoc(associd_t);
 extern  void	set_peerdstadr	(struct peer *, endpt *);
@@ -229,12 +229,11 @@ extern	void	record_clock_stats (struct peer *, const char *);
 extern	int	mprintf_clock_stats(struct peer *, const char *, ...)
 			NTP_PRINTF(2, 3);
 extern	void	record_raw_stats (sockaddr_u *srcadr, sockaddr_u *dstadr, l_fp *t1, l_fp *t2, l_fp *t3, l_fp *t4, int leap, int version, int mode, int stratum, int ppoll, int precision, double root_delay, double root_dispersion, uint32_t refid, u_int outcount);
-extern	void	check_leap_file	(int is_daily_check, uint32_t ntptime, const time_t * systime);
+extern	void	check_leap_file	(bool is_daily_check, time_t systime);
 extern	void	record_crypto_stats (sockaddr_u *, const char *);
 #ifdef DEBUG
 extern	void	record_timing_stats (const char *);
 #endif
-extern	char *	fstostr(time_t);	/* NTP timescale seconds */
 
 /* packetstamp.c */
 extern void	enable_packetstamps(int, sockaddr_u *);
@@ -408,8 +407,6 @@ extern int	sys_minclock;		/* minimum survivors */
 extern int	sys_minsane;		/* minimum candidates */
 extern int	sys_floor;		/* cluster stratum floor */
 extern int	sys_ceiling;		/* cluster stratum ceiling */
-extern uint8_t	sys_ttl[MAX_TTL];	/* ttl mapping vector */
-extern int	sys_ttlmax;		/* max ttl mapping vector index */
 
 /*
  * Statistics counters
@@ -471,7 +468,7 @@ extern	double	wander_threshold;
 extern	bool	initializing;	/* initializing flag */
 #ifdef ENABLE_DROPROOT
 extern	bool	droproot;	/* flag: try to drop root privileges after startup */
-extern	bool	root_dropped;	/* root has been dropped */
+/* extern	bool	root_dropped;	* root has been dropped UNUSED */
 extern char *user;		/* user to switch to */
 extern char *group;		/* group to switch to */
 extern const char *chrootdir;	/* directory to chroot() to */
