@@ -1,7 +1,7 @@
 /*
  * hextolfp - convert an ascii hex string to an l_fp number
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -62,7 +62,6 @@ hextolfp(
 	if (*cp != '\0' && !isspace((unsigned char)*cp))
 	    return false;
 
-	setlfpuint(*lfp, dec_i);
-	setlfpfrac(*lfp, dec_f);
+	*lfp = lfpinit(dec_i, dec_f);
 	return true;
 }
