@@ -1,7 +1,7 @@
 /*
  * numtoa - return asciized network numbers store in local array space
  */
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 #include <netinet/in.h>		/* ntohl */
