@@ -1,8 +1,8 @@
-#include <config.h>
+#include "config.h"
 
-#include <ntp.h>
-#include <ntp_fp.h>
-#include <refidsmear.h>
+#include "ntp.h"
+#include "ntp_fp.h"
+#include "refidsmear.h"
 
 /*
  * we want to test a refid format of:
@@ -17,7 +17,7 @@
 l_fp
 convertRefIDToLFP(uint32_t r)
 {
-	l_fp temp;
+	l_fp temp = 0;
 
 	r = ntohl(r);
 
