@@ -1,4 +1,4 @@
-# include <config.h>
+# include "config.h"
 
 #include <stdio.h>
 #include <sys/types.h>
