@@ -4,7 +4,7 @@
  * ATTENTION: Get approval from Dave Mills on all changes to this file!
  *
  */
-#include <config.h>
+#include "config.h"
 
 #include "ntp.h"
 #include "ntp_syslog.h"
@@ -84,7 +84,7 @@ set_sys_fuzz(
 	sys_fuzz = fuzz_val;
 	//INSIST(sys_fuzz >= 0);
 	//INSIST(sys_fuzz <= 1.0);
-	sys_fuzz_nsec = (long)(sys_fuzz * 1e9 + 0.5);
+	sys_fuzz_nsec = (long)(sys_fuzz * NS_PER_S + 0.5);
 }
 
 
@@ -106,26 +106,15 @@ get_ostime(
 	}
 
 	if (trunc_os_clock) {
-		ticks = (long)((tsp->tv_nsec * 1e-9) / sys_tick);
-		tsp->tv_nsec = (long)(ticks * 1e9 * sys_tick);
+		ticks = (long)((tsp->tv_nsec * S_PER_NS) / sys_tick);
+		tsp->tv_nsec = (long)(ticks * NS_PER_S * sys_tick);
 	}
 }
 
 
-/*
- * get_systime - return system time in NTP timestamp format.
- */
-void
-get_systime(
-	l_fp *now		/* system time */
-	)
-{
-	struct timespec ts;	/* seconds and nanoseconds */
-	get_ostime(&ts);
-	normalize_time(ts, sys_fuzz > 0.0 ? ntp_random() : 0, now);
-}
+static	void	normalize_time	(struct timespec, long, l_fp *);
 
-void
+static void
 normalize_time(
 	struct timespec ts,		/* seconds and nanoseconds */
 	long rand,
@@ -168,11 +157,10 @@ normalize_time(
 	if (cmp_tspec(ts, ts_min) < 0) {
 		ts_lam = sub_tspec(ts_min, ts);
 		if (ts_lam.tv_sec > 0 && !lamport_violated) {
-			msyslog(LOG_ERR,
-				"get_systime Lamport advance exceeds one second (%.9f)",
-				ts_lam.tv_sec +
-				    1e-9 * ts_lam.tv_nsec);
-			exit(1);
+		    msyslog(LOG_ERR,
+			"get_systime Lamport advance exceeds one second (%.9f)",
+			ts_lam.tv_sec + S_PER_NS * ts_lam.tv_nsec);
+		    exit(1);
 		}
 		if (!lamport_violated)
 			ts = ts_min;
@@ -187,16 +175,16 @@ normalize_time(
 	 * Add in the fuzz.
 	 */
 	dfuzz = rand * 2. / FRAC * sys_fuzz;
-	DTOLFP(dfuzz, &lfpfuzz);
-	L_ADD(&result, &lfpfuzz);
+	lfpfuzz = dtolfp(dfuzz);
+	result += lfpfuzz;
 
 	/*
 	 * Ensure result is strictly greater than prior result (ignoring
 	 * sys_residual's effect for now) once sys_fuzz has been
 	 * determined.
 	 */
-	if (!L_ISZERO(&lfp_prev) && !lamport_violated) {
-		if (!L_ISGTU(&result, &lfp_prev) &&
+	if (lfp_prev != 0 && !lamport_violated) {
+		if (!L_ISGTU(result, lfp_prev) &&
 		    sys_fuzz > 0.) {
 			msyslog(LOG_ERR, "ts_prev %s ts_min %s",
 				tspectoa(ts_prev_log),
@@ -207,8 +195,8 @@ normalize_time(
 			msyslog(LOG_ERR, "this fuzz %.9f",
 				dfuzz);
 			lfpdelta = lfp_prev;
-			L_SUB(&lfpdelta, &result);
-			LFPTOD(&lfpdelta, ddelta);
+			lfpdelta -= result;
+			ddelta = lfptod(lfpdelta);
 			msyslog(LOG_ERR,
 				"prev get_systime 0x%x.%08x is %.9f later than 0x%x.%08x",
 				lfpuint(lfp_prev), lfpfrac(lfp_prev),
@@ -217,11 +205,23 @@ normalize_time(
 	}
 	lfp_prev = result;
 	dfuzz_prev = dfuzz;
-	if (lamport_violated)
-		lamport_violated = false;
+	lamport_violated = false;
 	*now = result;
 }
 
+/*
+ * get_systime - return system time in NTP timestamp format.
+ */
+void
+get_systime(
+	l_fp *now		/* system time */
+	)
+{
+	struct timespec ts;	/* seconds and nanoseconds */
+	get_ostime(&ts);
+	normalize_time(ts, sys_fuzz > 0.0 ? ntp_random() : 0, now);
+}
+
 
 /*
  * adj_systime - adjust system time by the argument.
@@ -270,20 +270,20 @@ adj_systime(
 	if (sys_tick > sys_fuzz)
 		quant = sys_tick;
 	else
-		quant = 1e-6;
+		quant = S_PER_US;
 	ticks = (long)(dtemp / quant + .5);
-	adjtv.tv_usec = (long)(ticks * quant * 1.e6 + .5);
+	adjtv.tv_usec = (long)(ticks * quant * US_PER_S + .5);
 	/* The rounding in the conversions could push us over the
 	 * limits: make sure the result is properly normalised!
 	 * note: sign comes later, all numbers non-negative here.
 	 */
-	if (adjtv.tv_usec >= 1000000) {
+	if (adjtv.tv_usec >= US_PER_S) {
 		adjtv.tv_sec  += 1;
-		adjtv.tv_usec -= 1000000;
+		adjtv.tv_usec -= US_PER_S;
 		dtemp         -= 1.;
 	}
 	/* set the new residual with leftover from correction */
-	sys_residual = dtemp - adjtv.tv_usec * 1.e-6;
+	sys_residual = dtemp - adjtv.tv_usec * S_PER_US;
 
 	/*
 	 * Convert to signed seconds and microseconds for the Unix
@@ -307,6 +307,9 @@ adj_systime(
 
 /*
  * step_systime - step the system clock.
+ *
+ * if your timespec has a 64 bit time_t then you are 2038 ready.
+ * if your timespec has a 32 bit time_t, be sure to duck in 2038
  */
 
 bool
@@ -315,80 +318,29 @@ step_systime(
 	int (*settime)(struct timespec *)
 	)
 {
-	time_t pivot; /* for ntp era unfolding */
 	struct timespec timets, tslast, tsdiff;
-	struct calendar jd;
-	l_fp fp_ofs, fp_sys; /* offset and target system time in FP */
+	struct timespec ofs_ts; /* desired offset as teimspec */
 
-	/*
-	 * Get pivot time for NTP era unfolding. Since we don't step
-	 * very often, we can afford to do the whole calculation from
-	 * scratch. And we're not in the time-critical path yet.
-	 */
-#if NTP_SIZEOF_TIME_T > 4
-	/*
-	 * This code makes sure the resulting time stamp for the new
-	 * system time is in the 2^32 seconds starting at 1970-01-01,
-	 * 00:00:00 UTC.
-	 */
-	pivot = 0x80000000;
-#if USE_COMPILETIME_PIVOT
-	/*
-	 * Add the compile time minus 10 years to get a possible target
-	 * area of (compile time - 10 years) to (compile time + 126
-	 * years).  This should be sufficient for a given binary of
-	 * NTPD.
-	 */
-	if (ntpcal_get_build_date(&jd)) {
-		jd.year -= 10;
-		pivot += ntpcal_date_to_time(&jd);
-	} else {
-		msyslog(LOG_ERR,
-			"step_systime: assume 1970-01-01 as build date");
-	}
-#else
-	UNUSED_LOCAL(jd);
-#endif /* USE_COMPILETIME_PIVOT */
-#else
-	UNUSED_LOCAL(jd);
-	/* This makes sure the resulting time stamp is on or after
-	 * 1969-12-31/23:59:59 UTC and gives us additional two years,
-	 * from the change of NTP era in 2036 to the UNIX rollover in
-	 * 2038. (Minus one second, but that won't hurt.) We *really*
-	 * need a longer 'time_t' after that!  Or a different baseline,
-	 * but that would cause other serious trouble, too.
-	 */
-	pivot = 0x7FFFFFFF;
-#endif
-
-	/* get the complete jump distance as l_fp */
-	DTOLFP(sys_residual, &fp_sys);
-	DTOLFP(step,         &fp_ofs);
-	L_ADD(&fp_ofs, &fp_sys);
+	/* get the complete jump distance as timespec */
+        ofs_ts = d_to_tspec(step + sys_residual);
 
 	/* ---> time-critical path starts ---> */
 
-	/* get the current time as l_fp (without fuzz) and as struct timespec */
+	/* get the current time as, without fuzz, as struct timespec */
 	get_ostime(&timets);
-	fp_sys = tspec_stamp_to_lfp(timets);
 
-	/* only used for utmp/wtmpx time-step recording */
-	tslast.tv_sec = timets.tv_sec;
-	tslast.tv_nsec = timets.tv_nsec;
-
-	/* get the target time as l_fp */
-	L_ADD(&fp_sys, &fp_ofs);
-
-	/* unfold the new system time */
-	timets = lfp_stamp_to_tspec(fp_sys, &pivot);
+	/* add offset */
+	tslast = add_tspec(timets, ofs_ts);
 
 	/* now set new system time */
-	if (settime(&timets) != 0) {
+	if (settime(&tslast) != 0) {
 		msyslog(LOG_ERR, "step_systime: %m");
 		return false;
 	}
 
-	/* <--- time-critical path ended with 'ntp_set_tod()' <--- */
+	/* <--- time-critical path ended with call to the settime hook <--- */
+
+	/* only used for utmp/wtmpx time-step recording */
 
 	sys_residual = 0;
 	lamport_violated = (step < 0);
