@@ -5,11 +5,13 @@
  * Copyright 2015 by the NTPsec project contributors
  * SPDX-License-Identifier: BSD-3-Clause
  */
-#include <config.h>
+#include "config.h"
 #include "ntp_fp.h"
 #include "ntp_calendar.h"
 #include "parse.h"
 
+#define GPSORIGIN       2524953600u  /* GPS origin - NTP origin in seconds */
+
 void
 gpstolfp(
 	 int weeks,
