@@ -7,7 +7,7 @@
  *
  */
 
-#include <config.h>
+#include "config.h"
 #include "ntp_fp.h"
 #include "timespecops.h"
 #include "ntp_calendar.h"
@@ -19,6 +19,11 @@
 
 # include <stdio.h>
 
+/*
+ * PPS edge info
+ */
+#define SYNC_ONE	0x01
+
 extern clockformat_t *clockformats[];
 extern unsigned short nformats;
 
@@ -35,10 +40,10 @@ parse_timedout(
 
 	l_fp delt;
 
-	delt = tstamp->fp;
-	L_SUB(&delt, &parseio->parse_lastchar.fp);
+	delt = *tstamp;
+	delt -= parseio->parse_lastchar;
 	delta = lfp_uintv_to_tspec(delt);
-	if (cmp_tspec(delta, *del) == TIMESPEC_GREATER_THAN)
+       if (cmp_tspec(delta, *del) > 0)
 	{
 		parseprintf(DD_PARSE, ("parse: timedout: TRUE\n"));
 		return true;
@@ -481,7 +486,7 @@ updatetimeinfo(
 
 	parseprintf(DD_PARSE, ("updatetimeinfo status=0x%lx, time=%x\n",
 			       (long)parseio->parse_dtime.parse_state,
-	                       lfpuint(parseio->parse_dtime.parse_time.fp)));
+	                       lfpuint(parseio->parse_dtime.parse_time)));
 
 	return CVT_OK;		/* everything fine and dandy... */
 }
@@ -621,7 +626,7 @@ timepacket(
 	 * time stamp
 	 */
 	struct timespec ts = {t, clock_time.usecond * 1000};
-	parseio->parse_dtime.parse_time.fp = tspec_stamp_to_lfp(ts);
+	parseio->parse_dtime.parse_time = tspec_stamp_to_lfp(ts);
 	
 	parseio->parse_dtime.parse_format       = format;
 
