@@ -4,7 +4,7 @@
  *
  * This program is run to generate ntp_keyword.h
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -68,11 +68,8 @@ struct key_tok ntp_keywords[] = {
 /* authentication_command */
 { "controlkey",		T_ControlKey,		FOLLBY_TOKEN },
 { "requestkey",		T_Requestkey,		FOLLBY_TOKEN }, /* dummy */
-{ "crypto",		T_Crypto,		FOLLBY_TOKEN },
 { "keys",		T_Keys,			FOLLBY_STRING },
-{ "keysdir",		T_Keysdir,		FOLLBY_STRING },
 { "ntpsigndsocket",	T_NtpSignDsocket,	FOLLBY_STRING },
-{ "revoke",		T_Revoke,		FOLLBY_TOKEN },
 { "trustedkey",		T_Trustedkey,		FOLLBY_TOKEN },
 /* IPv4/IPv6 protocol override flag */
 { "-4",			T_Ipv4_flag,		FOLLBY_TOKEN },
@@ -92,15 +89,9 @@ struct key_tok ntp_keywords[] = {
 { "subtype",		T_Subtype,		FOLLBY_TOKEN },
 { "ttl",		T_Ttl,			FOLLBY_TOKEN },
 { "version",		T_Version,		FOLLBY_TOKEN },
-/* crypto_command */
-{ "host",		T_Host,			FOLLBY_STRING },
-{ "pw",			T_Pw,			FOLLBY_STRING },
-{ "randfile",		T_Randfile,		FOLLBY_STRING },
-{ "digest",		T_Digest,		FOLLBY_STRING },
 /*** MONITORING COMMANDS ***/
 /* stat */
 { "clockstats",		T_Clockstats,		FOLLBY_TOKEN },
-{ "cryptostats",	T_Cryptostats,		FOLLBY_TOKEN },
 { "loopstats",		T_Loopstats,		FOLLBY_TOKEN },
 { "peerstats",		T_Peerstats,		FOLLBY_TOKEN },
 { "protostats",		T_Protostats,		FOLLBY_TOKEN },
@@ -128,7 +119,6 @@ struct key_tok ntp_keywords[] = {
 { "minsane",		T_Minsane,		FOLLBY_TOKEN },
 { "floor",		T_Floor,		FOLLBY_TOKEN },
 { "ceiling",		T_Ceiling,		FOLLBY_TOKEN },
-{ "cohort",		T_Cohort,		FOLLBY_TOKEN },
 { "mindist",		T_Mindist,		FOLLBY_TOKEN },
 { "maxdisp",		T_Maxdisp,		FOLLBY_TOKEN },
 { "maxdist",		T_Maxdist,		FOLLBY_TOKEN },
@@ -229,8 +219,8 @@ typedef struct big_scan_state_tag {
 #define MAX_TOK_LEN	63
 
 const char *	current_keyword;/* for error reporting */
-big_scan_state	sst[MAXSTATES];	/* scanner FSM state entries */
-u_short		sst_highwater;	/* next entry index to consider */
+static big_scan_state	sst[MAXSTATES];	/* scanner FSM state entries */
+static u_short		sst_highwater;	/* next entry index to consider */
 char *		symb[1024];	/* map token ID to symbolic name */
 
 /* for libntp */
