@@ -11,7 +11,7 @@
  * SPDX-License-Identifier: BSD-2-clause
 */
 
-#include <config.h>
+#include "config.h"
 
 #ifdef HAVE_NETINFO_NI_H
 # include <netinfo/ni.h>
@@ -51,6 +51,11 @@
 #define NETINFO_CONFIG_DIR "/config/ntp"
 #endif
 
+/*
+ * Selection algorithm tuning parameters
+ */
+#define MAX_TTL		8	/* max ttl mapping vector size */
+
 /*
  * In the past, we told reference clocks from network peers by giving
  * the reference clocks magic address of a particular special form
@@ -140,13 +145,15 @@ typedef struct peer_resolved_ctx_tag {
 
 /* Limits */
 #define MAXPHONE	10	/* maximum number of phone strings */
-#define MAXPPS		20	/* maximum length of PPS device string */
+/* #define MAXPPS	20	* maximum length of PPS device string UNUSED */
 
 /*
  * Miscellaneous macros
  */
-#define ISEOL(c)	((c) == '#' || (c) == '\n' || (c) == '\0')
-#define ISSPACE(c)	((c) == ' ' || (c) == '\t')
+#ifdef HAVE_NETINFO_NI_H
+# define ISEOL(c)	((c) == '#' || (c) == '\n' || (c) == '\0')
+# define ISSPACE(c)	((c) == ' ' || (c) == '\t')
+#endif
 
 #define _UC(str)	((char *)(intptr_t)(str))
 
@@ -157,8 +164,6 @@ extern int yydebug;			/* ntp_parser.c (.y) */
 config_tree cfgt;			/* Parser output stored here */
 struct config_tree_tag *cfg_tree_history;	/* History of configs */
 char	*sys_phone[MAXPHONE] = {NULL};	/* ACTS phone numbers */
-char	default_keysdir[] = NTP_KEYSDIR;
-char	*keysdir = default_keysdir;	/* crypto keys directory */
 
 static char default_ntp_signd_socket[] =
 #ifdef MSSNTP_PATH
@@ -192,9 +197,6 @@ bool old_config_style = true;	/* A boolean flag, which when set,
 		   		 * format with a newline at the end of
 		  		 * every command is being used
 			 	 */
-int	cryptosw;		/* crypto command called */
-
-extern char *stats_drift_file;	/* name of the driftfile */
 
 /* FUNCTION PROTOTYPES */
 
@@ -221,7 +223,6 @@ static void free_config_setvar(config_tree *);
 static void free_config_system_opts(config_tree *);
 static void free_config_tinker(config_tree *);
 static void free_config_tos(config_tree *);
-static void free_config_ttl(config_tree *);
 static void free_config_unpeers(config_tree *);
 static void free_config_vars(config_tree *);
 
@@ -288,7 +289,6 @@ static void config_access(config_tree *);
 static void config_mdnstries(config_tree *);
 static void config_phone(config_tree *);
 static void config_setvar(config_tree *);
-static void config_ttl(config_tree *);
 static void config_fudge(config_tree *);
 static void config_peers(config_tree *);
 static void config_unpeers(config_tree *);
@@ -332,11 +332,6 @@ free_auth_node(
 		ptree->auth.keys = NULL;
 	}
 
-	if (ptree->auth.keysdir) {
-		free(ptree->auth.keysdir);
-		ptree->auth.keysdir = NULL;
-	}
-
 	if (ptree->auth.ntp_signd_socket) {
 		free(ptree->auth.ntp_signd_socket);
 		ptree->auth.ntp_signd_socket = NULL;
@@ -388,7 +383,6 @@ free_config_tree(
 	free_config_logconfig(ptree);
 	free_config_phone(ptree);
 	free_config_setvar(ptree);
-	free_config_ttl(ptree);
 	free_config_fudge(ptree);
 	free_config_vars(ptree);
 	free_config_peers(ptree);
@@ -1141,14 +1135,6 @@ config_auth(
 	int		i;
 	int		count;
 
-	/* Keysdir Command */
-	if (ptree->auth.keysdir) {
-		if (keysdir != default_keysdir)
-			free(keysdir);
-		keysdir = estrdup(ptree->auth.keysdir);
-	}
-
-
 	/* ntp_signd_socket Command */
 	if (ptree->auth.ntp_signd_socket) {
 		if (ntp_signd_socket != default_ntp_signd_socket)
@@ -1222,8 +1208,6 @@ free_config_auth(
 	config_tree *ptree
 	)
 {
-	destroy_attr_val_fifo(ptree->auth.crypto_cmd_list);
-	ptree->auth.crypto_cmd_list = NULL;
 	destroy_attr_val_fifo(ptree->auth.trusted_key_list);
 	ptree->auth.trusted_key_list = NULL;
 }
@@ -1262,10 +1246,6 @@ config_tos(
 			item = PROTO_FLOOR;
 			break;
 
-		case T_Cohort:
-			item = PROTO_COHORT;
-			break;
-
 		case T_Orphan:
 			item = PROTO_ORPHAN;
 			break;
@@ -2352,36 +2332,6 @@ free_config_setvar(
 }
 
 
-static void
-config_ttl(
-	config_tree *ptree
-	)
-{
-	size_t i = 0;
-	int_node *curr_ttl;
-
-	curr_ttl = HEAD_PFIFO(ptree->ttl);
-	for (; curr_ttl != NULL; curr_ttl = curr_ttl->link) {
-		if (i < COUNTOF(sys_ttl))
-			sys_ttl[i++] = (uint8_t)curr_ttl->i;
-		else
-			msyslog(LOG_INFO,
-				"ttl: Number of TTL entries exceeds %zu. Ignoring TTL %d...",
-				COUNTOF(sys_ttl), curr_ttl->i);
-	}
-	sys_ttlmax = i - 1;
-}
-
-
-static void
-free_config_ttl(
-	config_tree *ptree
-	)
-{
-	FREE_INT_FIFO(ptree->ttl);
-}
-
-
 static void
 config_fudge(
 	config_tree *ptree
@@ -3038,6 +2988,11 @@ config_unpeers(
 			continue;
 		}
 
+		if (curr_unpeer->addr == NULL) {
+			msyslog(LOG_ERR, "invalid address in unpeer command");
+			continue;
+		}
+		
 		ZERO(peeraddr);
 		AF(&peeraddr) = curr_unpeer->addr->type;
 		name = curr_unpeer->addr->address;
@@ -3046,7 +3001,7 @@ config_unpeers(
 		if (rc > 0) {
 			DPRINTF(1, ("unpeer: searching for %s\n",
 				    socktoa(&peeraddr)));
-			p = findexistingpeer(&peeraddr, NULL, NULL, -1, 0);
+			p = findexistingpeer(&peeraddr, NULL, NULL, -1);
 			if (p != NULL) {
 				msyslog(LOG_NOTICE, "unpeered %s",
 					socktoa(&peeraddr));
@@ -3128,7 +3083,7 @@ unpeer_name_resolved(
 		memcpy(&peeraddr, res->ai_addr, res->ai_addrlen);
 		DPRINTF(1, ("unpeer: searching for peer %s\n",
 			    socktoa(&peeraddr)));
-		peer = findexistingpeer(&peeraddr, NULL, NULL, -1, 0);
+		peer = findexistingpeer(&peeraddr, NULL, NULL, -1);
 		if (peer != NULL) {
 			af = AF(&peeraddr);
 			fam_spec = (AF_INET6 == af)
@@ -3246,7 +3201,6 @@ config_ntpd(
 	config_phone(ptree);
 	config_mdnstries(ptree);
 	config_setvar(ptree);
-	config_ttl(ptree);
 	config_vars(ptree);
 
 	io_open_sockets();
