@@ -2,7 +2,7 @@
  * ntp_io.c - input/output routines for ntpd.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <signal.h>
@@ -43,26 +43,19 @@
 /*
  * setsockopt does not always have the same arg declaration
  * across all platforms. If it's not defined we make it empty
+ * UNUSED
+ *
+ * #ifndef SETSOCKOPT_ARG_CAST
+ * #define SETSOCKOPT_ARG_CAST
+ * #endif
  */
 
-#ifndef SETSOCKOPT_ARG_CAST
-#define SETSOCKOPT_ARG_CAST
-#endif
-
-extern int listen_to_virtual_ips;
 
 #ifndef IPTOS_DSCP_EF
 #define IPTOS_DSCP_EF 0xb8
 #endif
 int qos = IPTOS_DSCP_EF;	/* QoS RFC 3246 */
 
-#ifdef ENABLE_LEAP_SMEAR
-/* TODO burnicki: This should be moved to ntp_timer.c, but if we do so
- * we get a linker error. Since we're running out of time before the leap
- * second occurs, we let it here where it just works.
- */
-int leap_smear_intv;
-#endif
 
 /*
  * NIC rule entry
@@ -82,7 +75,7 @@ struct nic_rule_tag {
  * NIC rule listhead.  Entries are added at the head so that the first
  * match in the list is the last matching rule specified.
  */
-nic_rule *nic_rule_list;
+static nic_rule *nic_rule_list;
 
 /*
  * This code is a remnant from when ntpd did asynchronous input using
@@ -124,7 +117,7 @@ endpt *	any6_interface;		/* wildcard ipv6 interface */
 endpt *	loopback_interface;	/* loopback ipv4 interface */
 
 u_int sys_ifnum;			/* next .ifnum to assign */
-int ninterfaces;			/* total # of interfaces */
+static int ninterfaces;			/* total # of interfaces */
 
 bool disable_dynamic_updates;	/* if true, scan interfaces once only */
 
@@ -181,7 +174,7 @@ struct vsock {
 	enum desc_type	type;
 };
 
-vsock_t	*fd_list;
+static vsock_t	*fd_list;
 
 #if defined(USE_ROUTING_SOCKET)
 /*
@@ -198,7 +191,7 @@ struct asyncio_reader {
 	void (*receiver)(struct asyncio_reader *);  /* input handler */
 };
 
-struct asyncio_reader *asyncio_reader_list;
+static struct asyncio_reader *asyncio_reader_list;
 
 static void delete_asyncio_reader (struct asyncio_reader *);
 static struct asyncio_reader *new_asyncio_reader (void);
@@ -226,13 +219,13 @@ struct remaddr {
 	endpt *			ep;
 };
 
-remaddr_t *	remoteaddr_list;
+static remaddr_t * remoteaddr_list;
 endpt *		ep_list;	/* complete endpt list */
 
 static endpt *	wildipv4;
 static endpt *	wildipv6;
 
-const int accept_wildcard_if_for_winnt = false;
+static const int accept_wildcard_if_for_winnt = false;
 
 static void	add_fd_to_list		(SOCKET, enum desc_type);
 static endpt *	find_addr_in_list	(sockaddr_u *);
@@ -1149,9 +1142,9 @@ convert_isc_if(
 	strlcpy(itf->name, isc_if->name, sizeof(itf->name));
 	itf->ifindex = isc_if->ifindex;
 	itf->family = (u_short)isc_if->af;
-	AF(&itf->sin) = itf->family;
-	AF(&itf->mask) = itf->family;
-	AF(&itf->bcast) = itf->family;
+	AF(&itf->sin) = (sa_family_t)itf->family;
+	AF(&itf->mask) = (sa_family_t)itf->family;
+	AF(&itf->bcast) = (sa_family_t)itf->family;
 	SET_PORT(&itf->sin, port);
 	SET_PORT(&itf->mask, port);
 	SET_PORT(&itf->bcast, port);
@@ -1280,17 +1273,17 @@ sau_from_netaddr(
 	)
 {
 	ZERO_SOCK(psau);
-	AF(psau) = (u_short)pna->family;
+	AF(psau) = (sa_family_t)pna->family;
 	switch (pna->family) {
 
 	case AF_INET:
-		memcpy(&psau->sa4.sin_addr, &pna->type.in,
-		       sizeof(psau->sa4.sin_addr));
+		memcpy(&SOCK_ADDR4(psau), &pna->type.in,
+		       sizeof(SOCK_ADDR4(psau)));
 		break;
 
 	case AF_INET6:
-		memcpy(&psau->sa6.sin6_addr, &pna->type.in6,
-		       sizeof(psau->sa6.sin6_addr));
+		memcpy(&SOCK_ADDR6(psau), &pna->type.in6,
+		       sizeof(SOCK_ADDR6(psau)));
 		break;
 	}
 }
@@ -1354,7 +1347,7 @@ check_flags6(
 	struct in6_ifreq ifr6;
 	int fd;
 
-	if (psau->sa.sa_family != AF_INET6)
+	if (AF(psau) != AF_INET6)
 		return false;
 	if ((fd = socket(AF_INET6, SOCK_DGRAM, 0)) < 0)
 		return false;
@@ -2117,7 +2110,6 @@ open_socket(
 }
 
 
-/* XXX ELIMINATE sendpkt similar in ntpq.c, ntp_io.c, ntptrace.c */
 /*
  * sendpkt - send a packet to the specified destination. Maintain a
  * send error cache so that only the first consecutive error for a
@@ -2127,13 +2119,12 @@ void
 sendpkt(
 	sockaddr_u *		dest,
 	endpt *	ep,
-	int			ttl,
 	void *			pkt,
 	int			len
 	)
 {
 	endpt *	src;
-	int	cc;
+	ssize_t	cc;
 
 	src = ep;
 	if (NULL == src) {
@@ -2141,13 +2132,13 @@ sendpkt(
 		 * unbound peer - drop request and wait for better
 		 * network conditions
 		 */
-		DPRINTF(2, ("sendpkt(dst=%s, ttl=%d, len=%d): no interface - IGNORED\n",
-			    socktoa(dest), ttl, len));
+		DPRINTF(2, ("sendpkt(dst=%s, len=%d): no interface - IGNORED\n",
+			    socktoa(dest), len));
 		return;
 	}
 
-	DPRINTF(2, ("sendpkt(%d, dst=%s, src=%s, ttl=%d, len=%d)\n",
-		    src->fd, socktoa(dest), socktoa(&src->sin), ttl, len));
+	DPRINTF(2, ("sendpkt(%d, dst=%s, src=%s, len=%d)\n",
+		    src->fd, socktoa(dest), socktoa(&src->sin), len));
 
 	cc = sendto(src->fd, pkt, (u_int)len, 0,
 		    &dest->sa, SOCKLEN(dest));
@@ -2206,14 +2197,14 @@ read_refclock_packet(
 		saved_errno = errno;
 		freerecvbuf(rb);
 		errno = saved_errno;
-		return buflen;
+		return (int)buflen;
 	}
 
 	/*
 	 * Got one. Mark how and when it got here,
 	 * put it on the full list and do bookkeeping.
 	 */
-	rb->recv_length = buflen;
+	rb->recv_length = (size_t)buflen;
 	rb->recv_peer = rp->srcclock;
 	rb->dstadr = 0;
 	rb->cast_flags = 0;
@@ -2228,7 +2219,7 @@ read_refclock_packet(
 		packets_received++;
 	}
 
-	return buflen;
+	return (int)buflen;
 }
 #endif	/* REFCLOCK */
 
@@ -2245,7 +2236,7 @@ read_network_packet(
 	)
 {
 	GETSOCKNAME_SOCKLEN_TYPE fromlen;
-	int buflen;
+	ssize_t buflen;
 	register struct recvbuf *rb;
 #ifdef USE_PACKET_TIMESTAMP
 	struct msghdr msghdr;
@@ -2270,7 +2261,7 @@ read_network_packet(
 
 		fromlen = sizeof(from);
 		buflen = recvfrom(fd, buf, sizeof(buf), 0,
-				  &from.sa, &fromlen);
+				       &from.sa, &fromlen);
 		DPRINTF(4, ("%s on (%lu) fd=%d from %s\n",
 			(itf->ignore_packets)
 			    ? "ignore"
@@ -2286,9 +2277,9 @@ read_network_packet(
 	fromlen = sizeof(rb->recv_srcadr);
 
 #ifndef USE_PACKET_TIMESTAMP
-	rb->recv_length = recvfrom(fd, (char *)&rb->recv_space,
-				   sizeof(rb->recv_space), 0,
-				   &rb->recv_srcadr.sa, &fromlen);
+	rb->recv_length = (size_t)recvfrom(fd, (char *)&rb->recv_space,
+				           sizeof(rb->recv_space), 0,
+				           &rb->recv_srcadr.sa, &fromlen);
 #else
 	iovec.iov_base        = &rb->recv_space;
 	iovec.iov_len         = sizeof(rb->recv_space);
@@ -2322,7 +2313,7 @@ read_network_packet(
 	}
 
 	DPRINTF(3, ("read_network_packet: fd=%d length %d from %s\n",
-		    fd, buflen, socktoa(&rb->recv_srcadr)));
+		    fd, (int)buflen, socktoa(&rb->recv_srcadr)));
 
 	/*
 	 * We used to drop network packets with addresses matching the magic
@@ -2582,7 +2573,7 @@ input_handler(
 	 * (ts_e - ts) is the amount of time we spent processing this
 	 * gob of file descriptors.  Log it.
 	 */
-	L_SUB(&ts_e, &ts);
+	ts_e -= ts;
 	collect_timing(NULL, "input handler", 1, &ts_e);
 	if (debug > 3)
 		msyslog(LOG_DEBUG,
@@ -2741,7 +2732,7 @@ findlocalinterface(
 	DPRINTF(4, ("findlocalinterface: kernel maps %s to %s\n",
 		    socktoa(addr), socktoa(&saddr)));
 
-	iface = getinterface(&saddr, flags);
+	iface = getinterface(&saddr, (uint32_t)flags);
 
 	/*
 	 * if we didn't find an exact match on saddr, find the closest
@@ -3254,7 +3245,8 @@ static void
 process_routing_msgs(struct asyncio_reader *reader)
 {
 	char buffer[5120];
-	int cnt, msg_type;
+	ssize_t cnt;
+        int msg_type;
 #ifdef HAVE_LINUX_RTNETLINK_H
 	struct nlmsghdr *nh;
 #else
