@@ -4,7 +4,7 @@
  * ATTENTION: Get approval from Dave Mills on all changes to this file!
  *
  */
-#include <config.h>
+#include "config.h"
 
 #include <limits.h>
 #include <stdio.h>
@@ -15,13 +15,17 @@
 
 #include "ntpd.h"
 #include "ntp_io.h"
-#include "ntp_proto.h"
 #include "ntp_calendar.h"
 #include "ntp_stdlib.h"
 #include "ntp_syscall.h"
+#include "timespecops.h"
 
-#define NANOSECONDS	1e9
-#define MICROSECONDS	1e6
+#define NTP_MAXFREQ	500e-6
+
+#ifdef HAVE_KERNEL_PLL
+# define FREQTOD(x)	((x) / 65536e6)            /* NTP to double */
+# define DTOFREQ(x)	((int32_t)((x) * 65536e6)) /* double to NTP */
+#endif
 
 /*
  * This is an implementation of the clock discipline algorithm described
@@ -41,9 +45,7 @@
 #define	CLOCK_ALLAN	11	/* Allan intercept (log2 s) */
 #define CLOCK_LIMIT	30	/* poll-adjust threshold */
 #define CLOCK_PGATE	4.	/* poll-adjust gate */
-#define PPS_MAXAGE	120	/* kernel pps signal timeout (s) */
-#define	FREQTOD(x)	((x) / 65536e6) /* NTP to double */
-#define	DTOFREQ(x)	((int32_t)((x) * 65536e6)) /* double to NTP */
+/* #define PPS_MAXAGE	120	* kernel pps signal timeout (s) UNUSED */
 
 /*
  * Clock discipline state machine. This is used to control the
@@ -156,13 +158,11 @@ bool	pll_control = false;	/* kernel support available */
 bool	kern_enable = true;	/* kernel support enabled */
 bool	hardpps_enable;		/* kernel PPS discipline enabled */
 bool	ext_enable;		/* external clock enabled */
-int	pps_stratum;		/* pps stratum */
-int	kernel_status;		/* from ntp_adjtime */
 bool	allow_panic = false;	/* allow panic correction (-g) */
 bool	force_step_once = false; /* always step time once at startup (-G) */
 bool	mode_ntpdate = false;	/* exit on first clock set (-q) */
 int	freq_cnt;		/* initial frequency clamp */
-int	freq_set;		/* initial set frequency switch */
+static int freq_set;		/* initial set frequency switch */
 
 /*
  * Clock state machine variables
@@ -752,6 +752,7 @@ local_clock(
 	 * lad set the step threshold to something ridiculous.
 	 */
 	if (pll_control && kern_enable && freq_cnt == 0) {
+		static int kernel_status;	/* from ntp_adjtime */
 
 		/*
 		 * We initialize the structure for the ntp_adjtime()
@@ -777,7 +778,7 @@ local_clock(
 				dtemp = -.5;
 			else
 				dtemp = .5;
-			ntv.offset = (long)(clock_offset * NANOSECONDS + dtemp);
+			ntv.offset = (long)(clock_offset * NS_PER_S + dtemp);
 #ifdef STA_NANO
 			ntv.constant = sys_poll;
 #else /* STA_NANO */
@@ -786,9 +787,9 @@ local_clock(
 			if (ntv.constant < 0)
 				ntv.constant = 0;
 
-			ntv.esterror = (long)(clock_jitter * MICROSECONDS);
+			ntv.esterror = (long)(clock_jitter * US_PER_S);
 			ntv.maxerror = (long)((sys_rootdelay / 2 +
-			    sys_rootdisp) * MICROSECONDS);
+			    sys_rootdisp) * US_PER_S);
 			ntv.status = STA_PLL;
 
 			/*
@@ -826,14 +827,14 @@ local_clock(
 			ntp_adjtime_error_handler(__func__, &ntv, ntp_adj_ret, errno, hardpps_enable, false, __LINE__ - 1);
 		}
 		pll_status = ntv.status;
-		clock_offset = ntv.offset / NANOSECONDS;
+		clock_offset = ntv.offset * S_PER_NS;
 		clock_frequency = FREQTOD(ntv.freq);
 
 		/*
 		 * If the kernel PPS is lit, monitor its performance.
 		 */
 		if (ntv.status & STA_PPSTIME) {
-			clock_jitter = ntv.jitter / NANOSECONDS;
+			clock_jitter = ntv.jitter * S_PER_NS;
 		}
 
 #if defined(STA_NANO) && NTP_API == 4
@@ -859,7 +860,7 @@ local_clock(
 	if (fabs(clock_frequency) > NTP_MAXFREQ)
 		msyslog(LOG_NOTICE,
 		    "frequency error %.0f PPM exceeds tolerance %.0f PPM",
-		    clock_frequency * MICROSECONDS, NTP_MAXFREQ * MICROSECONDS);
+		    clock_frequency * US_PER_S, NTP_MAXFREQ * US_PER_S);
 	dtemp = SQUARE(clock_frequency - drift_comp);
 	if (clock_frequency > NTP_MAXFREQ)
 		drift_comp = NTP_MAXFREQ;
@@ -920,9 +921,9 @@ local_clock(
 #ifdef DEBUG
 	if (debug)
 		printf(
-		    "local_clock: offset %.9f jit %.9f freq %.3f stab %.3f poll %d\n",
-		    clock_offset, clock_jitter, drift_comp * MICROSECONDS,
-		    clock_stability * MICROSECONDS, sys_poll);
+		    "local_clock: offset %.9f jit %.9f freq %.6f stab %.3f poll %d\n",
+		    clock_offset, clock_jitter, drift_comp * US_PER_S,
+		    clock_stability * US_PER_S, sys_poll);
 #endif /* DEBUG */
 	return (rval);
 #endif /* ENABLE_LOCKCLOCK */
@@ -1095,8 +1096,8 @@ set_freq(
 		}
 	}
 #endif /* HAVE_KERNEL_PLL */
-	mprintf_event(EVNT_FSET, NULL, "%s %.3f PPM", loop_desc,
-	    drift_comp * MICROSECONDS);
+	mprintf_event(EVNT_FSET, NULL, "%s %.6f PPM", loop_desc,
+	    drift_comp * US_PER_S);
 }
 #endif /* HAVE_LOCKCLOCK */
 
@@ -1265,7 +1266,7 @@ loop_config(
 		 * calibration phase.
 		 */
 		{
-			double ftemp = init_drift_comp / MICROSECONDS;
+			double ftemp = init_drift_comp / US_PER_S;
 			if (ftemp > NTP_MAXFREQ)
 				ftemp = NTP_MAXFREQ;
 			else if (ftemp < -NTP_MAXFREQ)
@@ -1308,7 +1309,7 @@ loop_config(
 		break;
 
 	case LOOP_PHI:		/* dispersion threshold (dispersion) */
-		clock_phi = freq / MICROSECONDS;
+		clock_phi = freq / US_PER_S;
 		break;
 
 	case LOOP_FREQ:		/* initial frequency (freq) */
@@ -1321,7 +1322,7 @@ loop_config(
 			freq = HUFFPUFF;
 		sys_hufflen = (int)(freq / HUFFPUFF);
 		sys_huffpuff = emalloc(sizeof(sys_huffpuff[0]) *
-		    sys_hufflen);
+		    (unsigned long)sys_hufflen);
 		for (i = 0; i < sys_hufflen; i++)
 			sys_huffpuff[i] = 1e9;
 		sys_mindly = 1e9;
