@@ -2,7 +2,7 @@
  * ntp_monitor - monitor ntpd statistics
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "ntpd.h"
 #include "ntp_io.h"
@@ -292,9 +292,9 @@ int mon_get_oldest_age(l_fp now)
     if (mru_entries == 0)
 	return 0;
     oldest = TAIL_DLIST(mon_mru_list, mru);
-    L_SUB(&now, &oldest->last);
+    now -= oldest->last;
     /* add one-half second to round up */
-    L_ADDUF(&now, 0x80000000);
+    now += 0x80000000;
     return lfpsint(now);
 }
 /*
@@ -353,9 +353,9 @@ ntp_monitor(
 	if (mon != NULL) {
 		mru_exists++;
 		interval_fp = rbufp->recv_time;
-		L_SUB(&interval_fp, &mon->last);
+		interval_fp -= mon->last;
 		/* add one-half second to round up */
-		L_ADDUF(&interval_fp, 0x80000000);
+		interval_fp += 0x80000000;
 		interval = lfpsint(interval_fp);
 		mon->last = rbufp->recv_time;
 		NSRCPORT(&mon->rmtadr) = NSRCPORT(&rbufp->recv_srcadr);
