@@ -1,7 +1,7 @@
 /*
  * ntp_peer.c - management of data maintained for peer associations
  */
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -9,7 +9,6 @@
 #include "ntpd.h"
 #include "ntp_lists.h"
 #include "ntp_stdlib.h"
-#include "ntp_control.h"
 #include "ntp_random.h"
 
 /*
@@ -37,7 +36,7 @@
 #define AM_MODES	7	/* number of rows and columns */
 #define NO_PEER		0	/* action when no peer is found */
 
-int AM[AM_MODES][AM_MODES] = {
+static int AM[AM_MODES][AM_MODES] = {
 /*			packet->mode					    */
 /* peer { UNSPEC,   ACTIVE,     PASSIVE,    CLIENT,     SERVER,     BCAST } */
 /* mode */
@@ -114,8 +113,7 @@ static struct peer init_peer_alloc[INIT_PEER_ALLOC]; /* init alloc */
 static struct peer *	findexistingpeer_name(const char *, u_short,
 					      struct peer *, int);
 static struct peer *	findexistingpeer_addr(sockaddr_u *,
-					      struct peer *, int,
-					      uint8_t);
+					      struct peer *, int);
 static void		free_peer(struct peer *, int);
 static void		getmorepeermem(void);
 static int		score(struct peer *);
@@ -200,18 +198,17 @@ struct peer *
 findexistingpeer_addr(
 	sockaddr_u *	addr,
 	struct peer *	start_peer,
-	int		mode,
-	uint8_t		cast_flags
+	int		mode
 	)
 {
 	struct peer *peer;
 
-	DPRINTF(2, ("findexistingpeer_addr(%s, %s, %d, 0x%x)\n",
+	DPRINTF(2, ("findexistingpeer_addr(%s, %s, %d)\n",
 		sockporttoa(addr),
 		(start_peer)
 		    ? sockporttoa(&start_peer->srcadr)
 		    : "NULL",
-		mode, (u_int)cast_flags));
+		    mode));
 
 	/*
 	 * start_peer is included so we can locate instances of the
@@ -225,9 +222,9 @@ findexistingpeer_addr(
 		peer = start_peer->adr_link;
 	
 	while (peer != NULL) {
-		DPRINTF(3, ("%s %s %d %d 0x%x 0x%x ", sockporttoa(addr),
+		DPRINTF(3, ("%s %s %d %d 0x%x ", sockporttoa(addr),
 			sockporttoa(&peer->srcadr), mode, peer->hmode,
-			(u_int)cast_flags, (u_int)peer->cast_flags));
+			(u_int)peer->cast_flags));
 		if ((-1 == mode || peer->hmode == mode) &&
 		    ADDR_PORT_EQ(addr, &peer->srcadr)) {
 			DPRINTF(3, ("found.\n"));
@@ -249,16 +246,13 @@ findexistingpeer(
 	sockaddr_u *	addr,
 	const char *	hostname,
 	struct peer *	start_peer,
-	int		mode,
-	uint8_t		cast_flags
-	)
+	int		mode)
 {
 	if (hostname != NULL)
 		return findexistingpeer_name(hostname, AF(addr),
 					     start_peer, mode);
 	else
-		return findexistingpeer_addr(addr, start_peer, mode,
-					     cast_flags);
+		return findexistingpeer_addr(addr, start_peer, mode);
 }
 
 
@@ -305,9 +299,8 @@ findpeer(
                  */
                 if (MODE_SERVER == pkt_mode && AM_PROCPKT == *action) {
                         pkt = &rbufp->recv_pkt;
-                        NTOHL_FP(&pkt->org, &pkt_org);
-                        if (!L_ISEQU(&p->org, &pkt_org) &&
-                            findmanycastpeer(rbufp))
+                        pkt_org = ntohl_fp(pkt->org);
+                        if (p->org != pkt_org && findmanycastpeer(rbufp))
                                 *action = AM_ERR;
                 }
 
@@ -630,7 +623,7 @@ newpeer(
 	uint8_t		cast_flags,
 	uint32_t		ttl,
 	keyid_t		key,
-	bool		initializing
+	bool		initializing1
 	)
 {
 	struct peer *	peer;
@@ -650,8 +643,7 @@ newpeer(
 	 * structure.
 	 */
 	if (dstadr != NULL) {
-		peer = findexistingpeer(srcadr, hostname, NULL, hmode,
-					cast_flags);
+		peer = findexistingpeer(srcadr, hostname, NULL, hmode);
 		while (peer != NULL) {
 			if (peer->dstadr == dstadr ||
 			    ((MDF_BCLNT & cast_flags) &&
@@ -662,13 +654,11 @@ newpeer(
 			    peer->dstadr == findinterface(srcadr))
 				break;
 
-			peer = findexistingpeer(srcadr, hostname, peer,
-						hmode, cast_flags);
+			peer = findexistingpeer(srcadr, hostname, peer,	hmode);
 		}
 	} else {
 		/* no endpt address given */
-		peer = findexistingpeer(srcadr, hostname, NULL, hmode,
-					cast_flags);
+		peer = findexistingpeer(srcadr, hostname, NULL, hmode);
 	}
 
 	/*
@@ -746,11 +736,11 @@ newpeer(
 	peer->precision = sys_precision;
 	peer->hpoll = peer->minpoll;
 	if (cast_flags & MDF_POOL)
-		peer_clear(peer, "POOL", initializing);
+		peer_clear(peer, "POOL", initializing1);
 	else if (cast_flags & MDF_BCAST)
-		peer_clear(peer, "BCST", initializing);
+		peer_clear(peer, "BCST", initializing1);
 	else
-		peer_clear(peer, "INIT", initializing);
+		peer_clear(peer, "INIT", initializing1);
 	if (mode_ntpdate)
 		peer_ntpdate++;
 
@@ -858,8 +848,8 @@ findmanycastpeer(
 	pkt = &rbufp->recv_pkt;
 	for (peer = peer_list; peer != NULL; peer = peer->p_link)
 		if (MDF_SOLICIT_MASK & peer->cast_flags) {
-			NTOHL_FP(&pkt->org, &p_org);
-			if (L_ISEQU(&p_org, &peer->org))
+			p_org = ntohl_fp(pkt->org);
+			if (p_org == peer->org)
 				break;
 		}
 
