@@ -1,17 +1,15 @@
 /*
  * ntp_proto.c - NTP version 4 protocol machinery
  *
- * ATTENTION: Get approval from Dave Mills on all changes to this file!
- *
  */
-#include <config.h>
+#include "config.h"
 
 #include "ntpd.h"
 #include "ntp_endian.h"
 #include "ntp_stdlib.h"
-#include "ntp_control.h"
 #include "ntp_leapsec.h"
 #include "refidsmear.h"
+#include "timespecops.h"
 
 #include <string.h>
 #include <stdio.h>
@@ -20,17 +18,53 @@
 #endif
 #include <unistd.h>
 
+/*
+ * Definitions for the clear() routine.  We use memset() to clear
+ * the parts of the peer structure which go to zero.  These are
+ * used to calculate the start address and length of the area.
+ */
+#define	CLEAR_TO_ZERO(p)	((char *)&((p)->clear_to_zero))
+#define	END_CLEAR_TO_ZERO(p)	((char *)&((p)->end_clear_to_zero))
+#define	LEN_CLEAR_TO_ZERO(p)	(END_CLEAR_TO_ZERO(p) - CLEAR_TO_ZERO(p))
+
 /*
  * traffic shaping parameters
  */
 #define	NTP_IBURST	6	/* packets in iburst */
 #define	RESP_DELAY	1	/* refclock burst delay (s) */
 
+/*
+ * Clock filter algorithm tuning parameters
+ */
+#define MAXDISPERSE	16.	/* max dispersion */
+#define NTP_FWEIGHT	.5	/* clock filter weight */
+
+/*
+ * Selection algorithm tuning parameters
+ */
+#define	NTP_MINCLOCK	3	/* min survivors */
+#define	NTP_MAXCLOCK	10	/* max candidates */
+#define MINDISPERSE	.001	/* min distance */
+#define CLOCK_SGATE	3.	/* popcorn spike gate */
+#define	NTP_ORPHWAIT	300	/* orphan wair (s) */
+
 /*
  * pool soliciting restriction duration (s)
  */
 #define	POOL_SOLICIT_WINDOW	8
 
+#define DIFF(x, y) (SQUARE((x) - (y)))
+
+/*
+ * Dealing with stratum.  0 gets mapped to 16 incoming, and back to 0
+ * on output.
+ */
+#define	PKT_TO_STRATUM(s)	((uint8_t)(((s) == (STRATUM_PKT_UNSPEC)) ?\
+				(STRATUM_UNSPEC) : (s)))
+
+#define	STRATUM_TO_PKT(s)	((uint8_t)(((s) == (STRATUM_UNSPEC)) ?\
+				(STRATUM_PKT_UNSPEC) : (s)))
+
 /*
  * peer_select groups statistics for a peer used by clock_select() and
  * clock_cluster().
@@ -47,7 +81,7 @@ typedef struct peer_select_tag {
  * times are in seconds.
  */
 uint8_t	sys_leap;		/* system leap indicator */
-uint8_t	xmt_leap;		/* leap indicator sent in client requests */
+static uint8_t	xmt_leap;		/* leap indicator sent in client requests */
 uint8_t	sys_stratum;		/* system stratum */
 int8_t	sys_precision;		/* local clock precision (log2 s) */
 double	sys_rootdelay;		/* roundtrip delay to primary source */
@@ -87,7 +121,7 @@ static int leap_vote_del;	/* leap consensus for delete */
 keyid_t	sys_private;		/* private value for session seed */
 int	sys_manycastserver;	/* respond to manycast client pkts */
 int	peer_ntpdate;		/* active peers in ntpdate mode */
-int	sys_survivors;		/* truest of the truechimers */
+static int sys_survivors;		/* truest of the truechimers */
 
 /*
  * TOS and multicast mapping stuff
@@ -97,11 +131,8 @@ int	sys_ceiling = STRATUM_UNSPEC - 1; /* cluster stratum ceiling */
 int	sys_minsane = 1;	/* minimum candidates */
 int	sys_minclock = NTP_MINCLOCK; /* minimum candidates */
 int	sys_maxclock = NTP_MAXCLOCK; /* maximum candidates */
-int	sys_cohort = 0;		/* cohort switch */
 int	sys_orphan = STRATUM_UNSPEC + 1; /* orphan stratum */
-int	sys_orphwait = NTP_ORPHWAIT; /* orphan wait */
-int	sys_ttlmax;		/* max ttl mapping vector index */
-uint8_t	sys_ttl[MAX_TTL];	/* ttl mapping vector */
+static int sys_orphwait = NTP_ORPHWAIT; /* orphan wait */
 
 /*
  * Statistics counters - first the good, then the bad
@@ -193,12 +224,12 @@ is_control_packet(
 
 /* Free a parsed_pkt structure allocated by parsed_packet(). In the
    event of a parse error, this function may be called from within
-   parse_packet() while the structure is only partially initalized, so
+   parse_packet() while the structure is only partially initialized, so
    we must be careful not to dereference uninitialized pointers.  This
    is achieved by making sure we use calloc() everywhere in
    parse_packet(), and then comparing to NULL before dereferencing.
 */
-void
+static void
 free_packet(
 	struct parsed_pkt *pkt
 	)
@@ -214,9 +245,9 @@ free_packet(
 		pkt->extensions = NULL;
 	}
 	free(pkt);
-};
+}
 
-struct parsed_pkt*
+static struct parsed_pkt*
 parse_packet(
 	struct recvbuf const* rbufp
 	)
@@ -283,7 +314,7 @@ parse_packet(
 			ext_count++;
 		}
 
-		pkt->num_extensions = ext_count;
+		pkt->num_extensions = (unsigned int)ext_count;
 		pkt->extensions = calloc(ext_count, sizeof (struct exten));
 		if(pkt->extensions == NULL) { goto fail; }
 
@@ -479,8 +510,8 @@ handle_fastxmit(
 	   (pkt->keyid_present &&
 	    authdecrypt(pkt->keyid,
 			(uint32_t*)rbufp->recv_space.X_recv_buffer,
-			rbufp->recv_length - (pkt->mac_len + 4),
-			pkt->mac_len + 4))) {
+			(int)(rbufp->recv_length - (pkt->mac_len + 4)),
+			(int)(pkt->mac_len + 4)))) {
 		xkeyid = pkt->keyid;
 	} else {
 		xkeyid = 0;
@@ -510,7 +541,7 @@ handle_procpkt(
 	peer->flash &= ~PKT_BOGON_MASK;
 
 	/* Duplicate detection */
-	if(pkt->xmt == lfp_to_uint64(peer->xmt)) {
+	if(pkt->xmt == peer->xmt) {
 		peer->flash |= BOGON1;
 		peer->oldpkt++;
 		return;
@@ -527,7 +558,7 @@ handle_procpkt(
 			peer->flash |= BOGON3;
 			peer->bogusorg++;
 			return;
-		} else if(pkt->org != lfp_to_uint64(peer->org)) {
+		} else if(pkt->org != peer->org) {
 			peer->flash |= BOGON2;
 			peer->bogusorg++;
 			return;
@@ -578,15 +609,14 @@ handle_procpkt(
 	   avoid loss of precision.
 	*/
 
-	const uint64_t dst = lfp_to_uint64(rbufp->recv_time);
 	const double t34 =
-	    (pkt->xmt >= dst) ?
-	    scalbn((double)(pkt->xmt - dst), -32) :
-	    -scalbn((double)(dst - pkt->xmt), -32);
+	    (pkt->xmt >= rbufp->recv_time) ?
+	    scalbn((double)(pkt->xmt - rbufp->recv_time), -32) :
+	    -scalbn((double)(rbufp->recv_time - pkt->xmt), -32);
 	const double t21 =
-	    (pkt->rec >= lfp_to_uint64(peer->org)) ?
-	    scalbn((double)(pkt->rec - lfp_to_uint64(peer->org)), -32) :
-	    -scalbn((double)(lfp_to_uint64(peer->org) - pkt->rec), -32);
+	    (pkt->rec >= peer->org) ?
+	    scalbn((double)(pkt->rec - peer->org), -32) :
+	    -scalbn((double)(peer->org - pkt->rec), -32);
 	const double theta = (t21 + t34) / 2.;
 	const double delta = fabs(t21 - t34);
 	const double epsilon = LOGTOD(sys_precision) +
@@ -618,9 +648,9 @@ handle_procpkt(
 	peer->rootdelay = scalbn((double)pkt->rootdelay, -16);
 	peer->rootdisp = scalbn((double)pkt->rootdisp, -16);
 	memcpy(&peer->refid, pkt->refid, REFIDLEN);
-	peer->reftime = uint64_to_lfp(pkt->reftime);
-	peer->rec = uint64_to_lfp(pkt->rec);
-	peer->xmt = uint64_to_lfp(pkt->xmt);
+	peer->reftime = pkt->reftime;
+	peer->rec = pkt->rec;
+	peer->xmt = pkt->xmt;
 	peer->dst = rbufp->recv_time;
 
 	record_raw_stats(&peer->srcadr,
@@ -790,9 +820,9 @@ receive(
 			   have to do this screwy buffer-length
 			   arithmetic in order to call it. */
 			!authdecrypt(pkt->keyid,
-				     (uint32_t*)rbufp->recv_space.X_recv_buffer,
-				     rbufp->recv_length - (pkt->mac_len + 4),
-				     pkt->mac_len + 4)) {
+				 (uint32_t*)rbufp->recv_space.X_recv_buffer,
+				 (int)(rbufp->recv_length - (pkt->mac_len + 4)),
+				 (int)(pkt->mac_len + 4))) {
 
 			sys_badauth++;
 			if(peer != NULL) {
@@ -992,7 +1022,7 @@ clock_update(
 	)
 {
 	double	dtemp;
-	l_fp	now;
+	time_t	now;
 #ifdef HAVE_LIBSCF_H
 	char	*fmri;
 #endif /* HAVE_LIBSCF_H */
@@ -1093,7 +1123,7 @@ clock_update(
 		memcpy(&sys_refid, "STEP", REFIDLEN);
 		sys_rootdelay = 0;
 		sys_rootdisp = 0;
-		L_CLR(&sys_reftime);
+		sys_reftime = 0;
 		sys_jitter = LOGTOD(sys_precision);
 		leapsec_reset_frame();
 		break;
@@ -1135,13 +1165,13 @@ clock_update(
 		if (leapsec == LSPROX_NOWARN) {
 			if (leap_vote_ins > leap_vote_del
 			    && leap_vote_ins > sys_survivors / 2) {
-				get_systime(&now);
-				leapsec_add_dyn(true, lfpuint(now), NULL);
+				time(&now);
+				leapsec_add_dyn(true, now);
 			}
 			if (leap_vote_del > leap_vote_ins
 			    && leap_vote_del > sys_survivors / 2) {
-				get_systime(&now);
-				leapsec_add_dyn(false, lfpuint(now), NULL);
+				time(&now);
+				leapsec_add_dyn(false, now);
 			}
 		}
 		break;
@@ -1260,7 +1290,7 @@ void
 peer_clear(
 	struct peer *peer,		/* peer structure */
 	const char *ident,		/* tally lights */
-	const bool initializing
+	const bool initializing1
 	)
 {
 	uint8_t	u;
@@ -1298,10 +1328,10 @@ peer_clear(
 	 * avoid implosion.
 	 */
 	peer->nextdate = peer->update = peer->outdate = current_time;
-	if (initializing) {
-		peer->nextdate += peer_associations;
+	if (initializing1) {
+		peer->nextdate += (unsigned long)peer_associations;
 	} else if (MODE_PASSIVE == peer->hmode) {
-		peer->nextdate += ntp_minpkt;
+		peer->nextdate += (unsigned long)ntp_minpkt;
 	} else {
 	    /*
 	     * Randomizing the next poll interval used to be done with
@@ -1485,7 +1515,7 @@ clock_filter(
 	 * packets.
 	 */
 	if (peer->filter_epoch[k] <= peer->epoch) {
-#if DEBUG
+#if defined(DEBUG) && DEBUG
 	if (debug > 1)
 		printf("clock_filter: old sample %lu\n", current_time -
 		    peer->filter_epoch[k]);
@@ -1570,9 +1600,10 @@ clock_select(void)
 	nlist = 1;
 	for (peer = peer_list; peer != NULL; peer = peer->p_link)
 		nlist++;
-	endpoint_size = ALIGNED_SIZE(nlist * 2 * sizeof(*endpoint));
-	peers_size = ALIGNED_SIZE(nlist * sizeof(*peers));
-	indx_size = ALIGNED_SIZE(nlist * 2 * sizeof(*indx));
+	endpoint_size = ALIGNED_SIZE(
+                             (unsigned long)(nlist * 2 * sizeof(*endpoint)));
+	peers_size = ALIGNED_SIZE((unsigned long)(nlist * sizeof(*peers)));
+	indx_size = ALIGNED_SIZE((unsigned long)(nlist * 2 * sizeof(*indx)));
 	octets = endpoint_size + peers_size + indx_size;
 	endpoint = erealloc(endpoint, octets);
 	peers = INC_ALIGNED_PTR(endpoint, endpoint_size);
@@ -2134,11 +2165,11 @@ peer_xmit(
 	xpkt.ppoll = peer->hpoll;
 	xpkt.precision = sys_precision;
 	xpkt.refid = sys_refid;
-	xpkt.rootdelay = HTONS_FP(DTOFP(sys_rootdelay));
+	xpkt.rootdelay = HTONS_FP(DTOUFP(sys_rootdelay));
 	xpkt.rootdisp =	 HTONS_FP(DTOUFP(sys_rootdisp));
-	HTONL_FP(&sys_reftime, &xpkt.reftime);
-	HTONL_FP(&peer->rec, &xpkt.org);
-	HTONL_FP(&peer->dst, &xpkt.rec);
+	xpkt.reftime = htonl_fp(sys_reftime);
+	xpkt.org = htonl_fp(peer->rec);
+	xpkt.rec = htonl_fp(peer->dst);
 
 	/*
 	 * If the received packet contains a MAC, the transmitted packet
@@ -2153,10 +2184,9 @@ peer_xmit(
 		 */
 		get_systime(&xmt_tx);
 		peer->org = xmt_tx;
-		HTONL_FP(&xmt_tx, &xpkt.xmt);
-		peer->t21_bytes = sendlen;
-		sendpkt(&peer->srcadr, peer->dstadr, sys_ttl[peer->ttl],
-		    &xpkt, sendlen);
+		xpkt.xmt = htonl_fp(xmt_tx);
+		peer->t21_bytes = (int)sendlen;
+		sendpkt(&peer->srcadr, peer->dstadr, &xpkt, (int)sendlen);
 		peer->sent++;
 		peer->outcount++;
 		peer->throttle += (1 << peer->minpoll) - 2;
@@ -2181,7 +2211,7 @@ peer_xmit(
 	 */
 	get_systime(&xmt_tx);
 	peer->org = xmt_tx;
-	HTONL_FP(&xmt_tx, &xpkt.xmt);
+	xpkt.xmt = htonl_fp(xmt_tx);
 	xkeyid = peer->keyid;
 	authlen = authencrypt(xkeyid, (uint32_t *)&xpkt, sendlen);
 	if (authlen == 0) {
@@ -2196,7 +2226,7 @@ peer_xmit(
 		exit(1);
 	}
 	peer->t21_bytes = sendlen;
-	sendpkt(&peer->srcadr, peer->dstadr, sys_ttl[peer->ttl], &xpkt,
+	sendpkt(&peer->srcadr, peer->dstadr, &xpkt,
 	    sendlen);
 	peer->sent++;
         peer->outcount++;
@@ -2216,7 +2246,7 @@ peer_xmit(
 static void
 leap_smear_add_offs(l_fp *t, l_fp *t_recv) {
 	UNUSED_ARG(t_recv);
-	L_ADD(t, &leap_smear.offset);
+	t += leap_smear.offset;
 }
 
 #endif	/* ENABLE_LEAP_SMEAR */
@@ -2295,7 +2325,7 @@ fast_xmit(
 		xpkt.ppoll = max(rpkt->ppoll, ntp_minpoll);
 		xpkt.precision = sys_precision;
 		xpkt.refid = sys_refid;
-		xpkt.rootdelay = HTONS_FP(DTOFP(sys_rootdelay));
+		xpkt.rootdelay = HTONS_FP(DTOUFP(sys_rootdelay));
 		xpkt.rootdisp = HTONS_FP(DTOUFP(sys_rootdisp));
 
 #ifdef ENABLE_LEAP_SMEAR
@@ -2305,12 +2335,12 @@ fast_xmit(
 			xpkt.refid = convertLFPToRefID(leap_smear.offset);
 			DPRINTF(2, ("fast_xmit: leap_smear.in_progress: refid %8x, smear %s\n",
 				ntohl(xpkt.refid),
-				lfptoa(&leap_smear.offset, 8)
+				lfptoa(leap_smear.offset, 8)
 				));
 		}
-		HTONL_FP(&this_ref_time, &xpkt.reftime);
+		xpkt.reftime = htonl_fp(this_ref_time);
 #else
-		HTONL_FP(&sys_reftime, &xpkt.reftime);
+		xpkt.reftime = htonl_fp(sys_reftime);
 #endif
 
 		xpkt.org = rpkt->xmt;
@@ -2319,9 +2349,9 @@ fast_xmit(
 		this_recv_time = rbufp->recv_time;
 		if (leap_smear.in_progress)
 			leap_smear_add_offs(&this_recv_time, NULL);
-		HTONL_FP(&this_recv_time, &xpkt.rec);
+		xpkt.rec = htonl_fp(this_recv_time);
 #else
-		HTONL_FP(&rbufp->recv_time, &xpkt.rec);
+		xpkt.rec = htonl_fp(rbufp->recv_time);
 #endif
 
 		get_systime(&xmt_tx);
@@ -2329,7 +2359,7 @@ fast_xmit(
 		if (leap_smear.in_progress)
 			leap_smear_add_offs(&xmt_tx, &this_recv_time);
 #endif
-		HTONL_FP(&xmt_tx, &xpkt.xmt);
+		xpkt.xmt = htonl_fp(xmt_tx);
 	}
 
 #ifdef ENABLE_MSSNTP
@@ -2346,8 +2376,7 @@ fast_xmit(
 	 */
 	sendlen = LEN_PKT_NOMAC;
 	if (rbufp->recv_length == sendlen) {
-		sendpkt(&rbufp->recv_srcadr, rbufp->dstadr, 0, &xpkt,
-		    sendlen);
+		sendpkt(&rbufp->recv_srcadr, rbufp->dstadr, &xpkt, sendlen);
 #ifdef DEBUG
 		if (debug)
 			printf(
@@ -2366,9 +2395,9 @@ fast_xmit(
 	 */
 	get_systime(&xmt_tx);
 	sendlen += authencrypt(xkeyid, (uint32_t *)&xpkt, sendlen);
-	sendpkt(&rbufp->recv_srcadr, rbufp->dstadr, 0, &xpkt, sendlen);
+	sendpkt(&rbufp->recv_srcadr, rbufp->dstadr, &xpkt, sendlen);
 	get_systime(&xmt_ty);
-	L_SUB(&xmt_ty, &xmt_tx);
+	xmt_ty -= xmt_tx;
 	sys_authdelay = xmt_ty;
 #ifdef DEBUG
 	if (debug)
@@ -2430,7 +2459,7 @@ pool_xmit(
 		/* copy_addrinfo_list ai_addr points to a sockaddr_u */
 		rmtadr = (sockaddr_u *)(void *)pool->ai->ai_addr;
 		pool->ai = pool->ai->ai_next;
-		p = findexistingpeer(rmtadr, NULL, NULL, MODE_CLIENT, 0);
+		p = findexistingpeer(rmtadr, NULL, NULL, MODE_CLIENT);
 	} while (p != NULL && pool->ai != NULL);
 	if (p != NULL)
 		return;	/* out of addresses, re-query DNS next poll */
@@ -2446,13 +2475,13 @@ pool_xmit(
 	xpkt.ppoll = pool->hpoll;
 	xpkt.precision = sys_precision;
 	xpkt.refid = sys_refid;
-	xpkt.rootdelay = HTONS_FP(DTOFP(sys_rootdelay));
+	xpkt.rootdelay = HTONS_FP(DTOUFP(sys_rootdelay));
 	xpkt.rootdisp = HTONS_FP(DTOUFP(sys_rootdisp));
-	HTONL_FP(&sys_reftime, &xpkt.reftime);
+	xpkt.reftime = htonl_fp(sys_reftime);
 	get_systime(&xmt_tx);
 	pool->org = xmt_tx;
-	HTONL_FP(&xmt_tx, &xpkt.xmt);
-	sendpkt(rmtadr, lcladr, sys_ttl[pool->ttl], &xpkt, LEN_PKT_NOMAC);
+	xpkt.xmt = htonl_fp(xmt_tx);
+	sendpkt(rmtadr, lcladr, &xpkt, LEN_PKT_NOMAC);
 	pool->sent++;
 	pool->throttle += (1 << pool->minpoll) - 2;
 #ifdef DEBUG
@@ -2636,10 +2665,10 @@ measure_precision(const bool verbose)
 	set_sys_tick_precision(measured_tick);
 	if (verbose) {
 		msyslog(LOG_INFO, "proto: precision = %.3f usec (%d)",
-			sys_tick * 1e6, sys_precision);
+			sys_tick * US_PER_S, sys_precision);
 		if (sys_fuzz < sys_tick) {
 			msyslog(LOG_NOTICE, "proto: fuzz beneath %.3f usec",
-				sys_fuzz * 1e6);
+				sys_fuzz * US_PER_S);
 		}
 	}
 }
@@ -2670,18 +2699,18 @@ measure_tick_fuzz(void)
 	max_repeats = 0;
 	repeats = 0;
 	changes = 0;
-	DTOLFP(MINSTEP, &minstep);
+	minstep = dtolfp(MINSTEP);
 	get_systime(&last);
 	for (i = 0; i < MAXLOOPS && changes < MINCHANGES; i++) {
 		get_systime(&val);
 		ldiff = val;
-		L_SUB(&ldiff, &last);
+		ldiff -= last;
 		last = val;
-		if (L_ISGT(&ldiff, &minstep)) {
+		if (L_ISGT(ldiff, minstep)) {
 			max_repeats = max(repeats, max_repeats);
 			repeats = 0;
 			changes++;
-			LFPTOD(&ldiff, diff);
+			diff = lfptod(ldiff);
 			tick = min(diff, tick);
 		} else {
 			repeats++;
@@ -2746,7 +2775,6 @@ void
 init_proto(const bool verbose)
 {
 	l_fp	dummy;
-	int	i;
 
 	/*
 	 * Fill in the sys_* stuff.  Default is don't listen to
@@ -2758,7 +2786,7 @@ init_proto(const bool verbose)
 	sys_peer = NULL;
 	sys_rootdelay = 0;
 	sys_rootdisp = 0;
-	L_CLR(&sys_reftime);
+	sys_reftime = 0;
 	sys_jitter = 0;
 	measure_precision(verbose);
 	get_systime(&dummy);
@@ -2768,10 +2796,6 @@ init_proto(const bool verbose)
 	orphwait = current_time + sys_orphwait;
 	proto_clr_stats();
 	use_stattime = current_time;
-	for (i = 0; i < MAX_TTL; i++) {
-		sys_ttl[i] = (uint8_t)((i * 256) / MAX_TTL);
-		sys_ttlmax = i;
-	}
 	hardpps_enable = false;
 	stats_control = true;
 }
@@ -2839,10 +2863,6 @@ proto_config(
 		sys_ceiling = (int)dvalue;
 		break;
 
-	case PROTO_COHORT:	/* cohort switch (cohort) */
-		sys_cohort = (int)dvalue;
-		break;
-
 	case PROTO_FLOOR:	/* stratum floor (floor) */
 		sys_floor = (int)dvalue;
 		break;
