@@ -1,7 +1,7 @@
 /*
  * ntp_refclock - processing support for reference clocks
  */
-#include <config.h>
+#include "config.h"
 
 #include "ntpd.h"
 #include "ntp_io.h"
@@ -11,6 +11,7 @@
 #include "ntp_assert.h"
 #include "lib_strbuf.h"
 #include "ntp_calendar.h"
+#include "timespecops.h"
 
 #include <stdio.h>
 
@@ -25,6 +26,12 @@
 #include "refclock_pps.h"
 #endif /* HAVE_PPSAPI */
 
+
+#define SAMPLE(x)	pp->coderecv = (pp->coderecv + 1) % MAXSTAGE; \
+			pp->filter[pp->coderecv] = (x); \
+			if (pp->coderecv == pp->codeproc) \
+				pp->codeproc = (pp->codeproc + 1) % MAXSTAGE;
+
 /*
  * Reference clock support is provided here by maintaining the fiction
  * that the clock is actually a peer.  As no packets are exchanged with
@@ -53,7 +60,7 @@
  * identified as a refclock by having a non-NULL procptr member. 
  */
 #define FUDGEFAC	.1	/* fudge correction factor */
-#define LF		0x0a	/* ASCII LF */
+/* #define LF		0x0a	* ASCII LF UNUSED */
 
 bool	cal_enable;		/* enable refclock calibrate */
 
@@ -142,7 +149,7 @@ init_refclock(void)
 	int i;
 
 	for (i = 0; i < (int)num_refclock_conf; i++)
-		if (refclock_conf[i]->clock_init != noentry)
+		if (refclock_conf[i]->clock_init)
 			(refclock_conf[i]->clock_init)();
 }
 
@@ -168,7 +175,7 @@ refclock_newpeer(
 	struct refclockproc *pp;
 
 	if (clktype >= num_refclock_conf ||
-		refclock_conf[clktype]->clock_start == noentry) {
+	    !refclock_conf[clktype]->clock_start) {
 		msyslog(LOG_ERR,
 			"refclock_newpeer: clock type %d invalid\n",
 			clktype);
@@ -237,7 +244,7 @@ refclock_unpeer(
 		return;
 
 	unit = peer->refclkunit;
-	if (peer->procptr->conf->clock_shutdown != noentry)
+	if (peer->procptr->conf->clock_shutdown)
 		(peer->procptr->conf->clock_shutdown)(unit, peer);
 	free(peer->procptr);
 	peer->procptr = NULL;
@@ -257,7 +264,7 @@ refclock_timer(
 
 	unit = p->refclkunit;
 	pp = p->procptr;
-	if (pp->conf->clock_timer != noentry)
+	if (pp->conf->clock_timer)
 		(*pp->conf->clock_timer)(unit, p);
 	if (pp->action != NULL && pp->nextaction <= current_time)
 		(*pp->action)(p);
@@ -317,7 +324,7 @@ refclock_transmit(
 	} else {
 		peer->burst--;
 	}
-	if (peer->procptr->conf->clock_poll != noentry)
+	if (peer->procptr->conf->clock_poll)
 		(peer->procptr->conf->clock_poll)(unit, peer);
 	poll_update(peer, peer->hpoll);
 }
@@ -363,8 +370,8 @@ refclock_process_offset(
 
 	pp->lastrec = lastrec;
 	lftemp = lasttim;
-	L_SUB(&lftemp, &lastrec);
-	LFPTOD(&lftemp, doffset);
+	lftemp -= lastrec;
+	doffset = lfptod(lftemp);
 	SAMPLE(doffset + fudge);
 }
 
@@ -391,7 +398,7 @@ refclock_process_f(
 	double fudge
 	)
 {
-	l_fp offset, ltemp;
+	l_fp offset = 0, ltemp = 0;
 	uint32_t sec;
 
 	/*
@@ -408,8 +415,8 @@ refclock_process_f(
 
 	setlfpuint(offset, sec);
 	setlfpfrac(offset, 0);
-	DTOLFP(pp->nsec / 1e9, &ltemp);
-	L_ADD(&offset, &ltemp);
+	ltemp = dtolfp(pp->nsec * S_PER_NS);
+	offset += ltemp;
 	refclock_process_offset(pp, offset, pp->lastrec, fudge);
 	return true;
 }
@@ -861,7 +868,7 @@ refclock_control(
 	/*
 	 * Check for valid address and running peer
 	 */
-	peer = findexistingpeer(srcadr, NULL, NULL, -1, 0);
+	peer = findexistingpeer(srcadr, NULL, NULL, -1);
 
 	if (NULL == peer)
 		return;
@@ -942,7 +949,7 @@ refclock_control(
 	/*
 	 * Give the stuff to the clock
 	 */
-	if (peer->procptr->conf->clock_control != noentry)
+	if (peer->procptr->conf->clock_control)
 		(peer->procptr->conf->clock_control)(unit, in, out, peer);
 }
 
@@ -1087,7 +1094,7 @@ refclock_catcher(
 	 * Convert to signed fraction offset and stuff in median filter.
 	 */
 	setlfpuint(pp->lastrec, (uint32_t)ap->ts.tv_sec + JAN_1970);
-	dtemp = ap->ts.tv_nsec / 1e9;
+	dtemp = ap->ts.tv_nsec * S_PER_NS;
 	setlfpfrac(pp->lastrec, (uint32_t)(dtemp * FRAC));
 	if (dtemp > .5)
 		dtemp -= 1.;
