@@ -1,15 +1,17 @@
 /*
  * ntp_util.c - stuff I didn't have any other place for
  */
-#include <config.h>
+#include "config.h"
 
-#include "ntpd.h"
-#include "ntp_filegen.h"
-#include "ntp_stdlib.h"
+#include "lib_strbuf.h"
 #include "ntp_assert.h"
 #include "ntp_calendar.h"
+#include "ntp_config.h"
+#include "ntp_filegen.h"
 #include "ntp_leapsec.h"
-#include "lib_strbuf.h"
+#include "ntp_stdlib.h"
+#include "ntpd.h"
+#include "timespecops.h"
 
 #include <stdio.h>
 #include <libgen.h>
@@ -26,12 +28,7 @@
 /*
  * Defines used by the leapseconds stuff
  */
-#define	MAX_TAI	100			/* max TAI offset (s) */
-#define	L_DAY	86400UL			/* seconds per day */
-#define	L_YEAR	(L_DAY * 365)		/* days per year */
-#define	L_LYEAR	(L_YEAR + L_DAY)	/* days per leap year */
-#define	L_4YEAR	(L_LYEAR + 3 * L_YEAR)	/* days per leap cycle */
-#define	L_CENT	(L_4YEAR * 25)		/* days per century */
+#define MJD_1900		15020	/* MJD for 1 Jan 1900 */
 
 /*
  * This contains odds and ends, including the hourly stats, various
@@ -41,10 +38,10 @@
  * File names
  */
 static	char *key_file_name;		/* keys file name */
-static char	  *leapfile_name;		/* leapseconds file name */
+static char *leapfile_name;		/* leapseconds file name */
 static struct stat leapfile_stat;	/* leapseconds file stat() buffer */
-static bool        have_leapfile = false;
-char	*stats_drift_file;		/* frequency file name */
+static bool have_leapfile = false;
+char *stats_drift_file;			/* frequency file name */
 static double wander_resid;		/* last frequency update */
 double	wander_threshold = 1e-7;	/* initial frequency threshold */
 
@@ -58,7 +55,6 @@ double	wander_threshold = 1e-7;	/* initial frequency threshold */
 
 char statsdir[MAXFILENAME] = NTP_VAR;
 static FILEGEN clockstats;
-static FILEGEN cryptostats;
 static FILEGEN loopstats;
 static FILEGEN peerstats;
 static FILEGEN protostats;
@@ -84,7 +80,7 @@ static double prev_drift_comp;		/* last frequency update */
 static	void	record_sys_stats(void);
 static	void	record_use_stats(void);
 	void	ntpd_time_stepped(void);
-static  void	check_leap_expiration(int, uint32_t, const time_t*);
+static  void	check_leap_expiration(bool, time_t);
 
 /* 
  * Prototypes
@@ -109,7 +105,6 @@ uninit_util(void)
 		key_file_name = NULL;
 	}
 	filegen_unregister("clockstats");
-	filegen_unregister("cryptostats");
 	filegen_unregister("loopstats");
 	filegen_unregister("rawstats");
 	filegen_unregister("sysstats");
@@ -128,7 +123,6 @@ void
 init_util(void)
 {
 	filegen_register(statsdir, "clockstats",  &clockstats);
-	filegen_register(statsdir, "cryptostats", &cryptostats);
 	filegen_register(statsdir, "loopstats",	  &loopstats);
 	filegen_register(statsdir, "rawstats",	  &rawstats);
 	filegen_register(statsdir, "sysstats",	  &sysstats);
@@ -153,7 +147,7 @@ init_util(void)
  */
 #define IGNORE(r) do{if(r){}}while(0)
 
-void drift_write(char *driftfile, double drift)
+static void drift_write(char *driftfile, double drift)
 {
 	int fd;
 	char tmpfile[PATH_MAX], driftcopy[PATH_MAX];
@@ -166,7 +160,7 @@ void drift_write(char *driftfile, double drift)
 	    msyslog(LOG_ERR, "frequency file %s: %m", tmpfile);
 	    return;
 	}
-	snprintf(driftval, sizeof(driftval), "%.3f\n", drift);
+	snprintf(driftval, sizeof(driftval), "%.6f\n", drift);
 	IGNORE(write(fd, driftval, strlen(driftval)));
 	(void)close(fd);
 	/* atomic */
@@ -194,8 +188,8 @@ write_stats(void)
 #ifdef DEBUG
 		if (debug)
 			printf("write_stats: frequency %.6lf thresh %.6lf, freq %.6lf\n",
-			    (prev_drift_comp - drift_comp) * 1e6, wander_resid *
-			    1e6, drift_comp * 1e6);
+			    (prev_drift_comp - drift_comp) * US_PER_S,
+                             wander_resid * US_PER_S, drift_comp * US_PER_S);
 #endif
 		if (fabs(prev_drift_comp - drift_comp) < wander_resid) {
 			wander_resid *= 0.5;
@@ -203,7 +197,7 @@ write_stats(void)
 		}
 		prev_drift_comp = drift_comp;
 		wander_resid = wander_threshold;
-		drift_write(stats_drift_file, drift_comp * 1e6);
+		drift_write(stats_drift_file, drift_comp * US_PER_S);
 	}
 }
 
@@ -211,7 +205,7 @@ write_stats(void)
 /*
  * stats_config - configure the stats operation
  */
-bool drift_read(const char *drift_file, double *drift)
+static bool drift_read(const char *drift_file, double *drift)
 {
 	FILE *fp;
 	if ((fp = fopen(drift_file, "r")) == NULL) {
@@ -236,9 +230,8 @@ stats_config(
 {
 	FILE	*fp;
 	const char *value;
-	int	len;
+	size_t	len;
 	double	new_drift = 0;
-	l_fp	now;
 	time_t  ttnow;
 
 	value = invalue;
@@ -253,7 +246,7 @@ stats_config(
 			break;
 
 		stats_drift_file = erealloc(stats_drift_file, len + 1);
-		memcpy(stats_drift_file, value, (size_t)(len+1));
+		memcpy(stats_drift_file, value, len+1);
 
 		/*
 		 * Open drift file and read frequency. If the file is
@@ -277,7 +270,7 @@ stats_config(
 			    (int)sizeof(statsdir) - 2);
 		} else {
 			bool add_dir_sep;
-			int value_l;
+			size_t value_l;
 
 			/* Add a DIR_SEP unless we already have one. */
 			value_l = strlen(value);
@@ -329,23 +322,22 @@ stats_config(
 		{
 			leap_signature_t lsig;
 
-			get_systime(&now);
 			time(&ttnow);
 			leapsec_getsig(&lsig);
 			mprintf_event(EVNT_TAI, NULL,
-				      "%d leap %s %s %s",
-				      lsig.taiof,
-				      fstostr(lsig.ttime),
-				      leapsec_expired(lfpuint(now), NULL)
-					  ? "expired"
-					  : "expires",
-				      fstostr(lsig.etime));
+				"%d leap %s %s %s",
+				lsig.taiof,
+				rfc3339time(lsig.ttime),
+				leapsec_expired(ttnow)
+					? "expired"
+					: "expires",
+				rfc3339time(lsig.etime));
 			have_leapfile = true;
 
 			/* force an immediate daily expiration check of
 			 * the leap seconds table
 			 */
-			check_leap_expiration(true, lfpuint(now), &ttnow);
+			check_leap_expiration(true, ttnow);
 		}
 		break;
 
@@ -383,7 +375,7 @@ record_peer_stats(
 	get_systime(&now);
 	filegen_setup(&peerstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (peerstats.fp != NULL) {
 		fprintf(peerstats.fp,
 		    "%lu %s %s %x %.9f %.9f %.9f %.9f\n", day,
@@ -434,11 +426,11 @@ record_loop_stats(
 	get_systime(&now);
 	filegen_setup(&loopstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (loopstats.fp != NULL) {
-		fprintf(loopstats.fp, "%lu %s %.9f %.3f %.9f %.6f %d\n",
-		    day, ulfptoa(now, 3), offset, freq * 1e6, jitter,
-		    wander * 1e6, spoll);
+		fprintf(loopstats.fp, "%lu %s %.9f %.6f %.9f %.6f %d\n",
+		    day, ulfptoa(now, 3), offset, freq * US_PER_S, jitter,
+		    wander * US_PER_S, spoll);
 		fflush(loopstats.fp);
 	}
 }
@@ -468,7 +460,7 @@ record_clock_stats(
 	get_systime(&now);
 	filegen_setup(&clockstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (clockstats.fp != NULL) {
 		fprintf(clockstats.fp, "%lu %s %s %s\n", day,
 		    ulfptoa(now, 3), peerlabel(peer), text);
@@ -529,7 +521,6 @@ record_raw_stats(
 	double	root_dispersion,/* seconds */
 	uint32_t	refid,
 	u_int	outcount
-
 	)
 {
 	l_fp	now;
@@ -541,7 +532,7 @@ record_raw_stats(
 	get_systime(&now);
 	filegen_setup(&rawstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (rawstats.fp != NULL) {
 		fprintf(rawstats.fp, "%lu %s %s %s %s %s %s %s %d %d %d %d %d %d %.6f %.6f %s %d\n",
 		    day, ulfptoa(now, 3),
@@ -586,7 +577,7 @@ record_sys_stats(void)
 	get_systime(&now);
 	filegen_setup(&sysstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (sysstats.fp != NULL) {
 		fprintf(sysstats.fp,
 		    "%lu %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
@@ -625,7 +616,7 @@ void record_use_stats(void)
 	get_systime(&now);
 	filegen_setup(&usestats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (usestats.fp != NULL) {
 		double utime, stime;
 		getrusage(RUSAGE_SELF, &usage);
@@ -639,11 +630,11 @@ void record_use_stats(void)
 		    "%lu %s %lu %.3f %.3f %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
 		    day, ulfptoa(now, 3), current_time - use_stattime,
 		    utime, stime,
-		    usage.ru_minflt -  oldusage.ru_minflt,
-		    usage.ru_majflt -  oldusage.ru_majflt,
-		    usage.ru_nswap -   oldusage.ru_nswap,
-		    usage.ru_inblock - oldusage.ru_inblock,
-		    usage.ru_oublock - oldusage.ru_oublock,
+		    usage.ru_minflt -   oldusage.ru_minflt,
+		    usage.ru_majflt -   oldusage.ru_majflt,
+		    usage.ru_nswap -    oldusage.ru_nswap,
+		    usage.ru_inblock -  oldusage.ru_inblock,
+		    usage.ru_oublock -  oldusage.ru_oublock,
 		    usage.ru_nvcsw -    oldusage.ru_nvcsw,
 		    usage.ru_nivcsw -   oldusage.ru_nivcsw,
 		    usage.ru_nsignals - oldusage.ru_nsignals,
@@ -678,7 +669,7 @@ record_proto_stats(
 	get_systime(&now);
 	filegen_setup(&protostats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (protostats.fp != NULL) {
 		fprintf(protostats.fp, "%lu %s %s\n", day,
 		    ulfptoa(now, 3), str);
@@ -710,7 +701,7 @@ record_timing_stats(
 	get_systime(&now);
 	filegen_setup(&timingstats, lfpuint(now));
 	day = lfpuint(now) / 86400 + MJD_1900;
-	lfpuint(now) %= 86400;
+	setlfpuint(now, lfpuint(now) % 86400);
 	if (timingstats.fp != NULL) {
 		fprintf(timingstats.fp, "%lu %s %s\n", day, lfptoa(now,
 		    3), text);
@@ -732,9 +723,8 @@ record_timing_stats(
  */
 void
 check_leap_file(
-	int           is_daily_check,
-	uint32_t      ntptime       ,
-	const time_t *systime
+	bool   is_daily_check,
+	time_t systime
 	)
 {
 	/* just do nothing if there is no leap file */
@@ -749,7 +739,7 @@ check_leap_file(
 	else if (!have_leapfile)
 		return;
 
-	check_leap_expiration(is_daily_check, ntptime, systime);
+	check_leap_expiration(is_daily_check, systime);
 }
 
 /*
@@ -757,9 +747,8 @@ check_leap_file(
  */
 static void
 check_leap_expiration(
-	int           is_daily_check,
-	uint32_t      ntptime       ,
-	const time_t *systime
+	bool   is_daily_check,
+	time_t systime
 	)
 {
 	static const char * const logPrefix = "leapsecond file";
@@ -769,7 +758,7 @@ check_leap_expiration(
 	 * level and frequency (once/hour or once/day, depending on the
 	 * state.
 	 */
-	rc = leapsec_daystolive(ntptime, systime);	
+	rc = leapsec_daystolive(systime);
 	if (rc == 0) {
 		msyslog(LOG_WARNING,
 			"%s ('%s'): will expire in less than one day",
@@ -795,7 +784,7 @@ getauthkeys(
 	const char *keyfile
 	)
 {
-	int len;
+	size_t len;
 
 	len = strlen(keyfile);
 	if (!len)
@@ -819,7 +808,7 @@ rereadkeys(void)
 }
 
 
-#if __UNUSED__
+#ifdef __UNUSED__
 /*
  * ntp_exit - document explicitly that ntpd has exited
  */
@@ -831,28 +820,6 @@ ntp_exit(int retval)
 }
 #endif
 
-/*
- * fstostr - prettyprint NTP seconds
- */
-char * fstostr(
-	time_t	ntp_stamp
-	)
-{
-	char *		buf;
-	struct calendar tm;
-
-	LIB_GETBUF(buf);
-	if (ntpcal_ntp_to_date(&tm, (uint32_t)ntp_stamp, NULL) < 0)
-		snprintf(buf, LIB_BUFLENGTH, "ntpcal_ntp_to_date: %ld: range error",
-			 (long)ntp_stamp);
-	else
-		snprintf(buf, LIB_BUFLENGTH, "%04d%02d%02d%02d%02d",
-			 tm.year, tm.month, tm.monthday,
-			 tm.hour, tm.minute);
-	return buf;
-}
-
-
 /*
  * ntpd_time_stepped is called back by step_systime(), allowing ntpd
  * to do any one-time processing necessitated by the step.
@@ -869,6 +836,6 @@ ntpd_time_stepped(void)
 	if (MON_OFF != mon_enabled) {
 		saved_mon_enabled = mon_enabled;
 		mon_stop(MON_OFF);
-		mon_start(saved_mon_enabled);
+		mon_start((int)saved_mon_enabled);
 	}
 }
