@@ -2,7 +2,7 @@
  * ntpd.c - main program for the fixed point NTP daemon
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "ntp_machine.h"
 #include "ntpd.h"
@@ -33,15 +33,11 @@
 
 #include "version.h"
 
-extern bool sandbox(const bool droproot,
-		    const char *user, const char *group,
-		    const char *chrootdir,
-		    bool want_dynamic_interface_tracking);
-
 void catchQuit (int sig);
 static volatile int signo = 0;
 /* In an ideal world, 'finish_safe()' would declared as noreturn... */
-static	void		finish_safe	(int);
+static	void	finish_safe	(int)
+			__attribute__	((__noreturn__));
 
 #ifdef SIGDANGER
 # include <ulimit.h>
@@ -49,11 +45,9 @@ static	void		finish_safe	(int);
 
 #if defined(HAVE_DNS_SD_H) && defined(ENABLE_MDNS_REGISTRATION)
 # include <dns_sd.h>
-DNSServiceRef mdns;
+static DNSServiceRef mdns;
 #endif
 
-#include <sodium.h>
-
 static void check_minsane(void);
 
 static bool need_priority = false;
@@ -78,7 +72,7 @@ static const char *driftfile, *pidfile;
  * attempt fails, then try again once per minute for up to 5
  * times. After all, we may be starting before mDNS.
  */
-bool mdnsreg = false;
+static bool mdnsreg = false;
 int mdnstries = 5;
 #endif  /* ENABLE_MDNS_REGISTRATION */
 
@@ -110,11 +104,12 @@ static	void	lessdebug	(int);
 static	void	no_debug	(int);
 # endif	/* !DEBUG */
 
-int	saved_argc;
-char **	saved_argv;
+static int	saved_argc;
+static char **	saved_argv;
 
 int		ntpdmain		(int, char **);
-static void	mainloop		(void);
+static void	mainloop		(void)
+			__attribute__	((__noreturn__));
 static void	set_process_priority	(void);
 static void	assertion_failed	(const char *, int,
 					 isc_assertiontype_t,
@@ -122,16 +117,16 @@ static void	assertion_failed	(const char *, int,
 			__attribute__	((__noreturn__));
 static void	library_fatal_error	(const char *, int,
 					 const char *, va_list)
-					ISC_FORMAT_PRINTF(3, 0);
+					ISC_FORMAT_PRINTF(3, 0)
+			__attribute__	((__noreturn__));
 static void	library_unexpected_error(const char *, int,
 					 const char *, va_list)
 					ISC_FORMAT_PRINTF(3, 0);
 
-#define ALL_OPTIONS "46c:dD:f:gGhi:I:k:l:LmnNp:PqRs:t:u:UVw:xyYzZ"
+#define ALL_OPTIONS "46c:dD:f:gGhi:I:k:l:LmnNp:PqRs:t:u:UVw:xzZ"
 static const struct option longoptions[] = {
     { "ipv4",		    0, 0, '4' },
     { "ipv6",		    0, 0, '6' },
-    { "noauthreq",	    0, 0, 'A' },
     { "configfile",	    1, 0, 'c' },
     { "debug",		    0, 0, 'd' },
     { "set-debug-level",    1, 0, 'D' },
@@ -146,14 +141,14 @@ static const struct option longoptions[] = {
     { "novirtualips",	    0, 0, 'L' },
     { "nofork",		    0, 0, 'n' },
     { "nice",		    0, 0, 'N' },
+    { "pidfile",	    1, 0, 'p' },
+    { "priority",	    1, 0, 'P' },
     { "quit",		    0, 0, 'q' },
     { "dumpopts",	    0, 0, 'R' },
     { "statsdir",	    1, 0, 's' },
     { "trustedkey",	    1, 0, 't' },
     { "user",		    1, 0, 'u' },
     { "updateinterval",	    1, 0, 'U' },
-    { "capture",	    1, 0, 'y' },
-    { "replay",		    1, 0, 'Y' },
     { "var",		    1, 0, 'z' },
     { "dvar",		    1, 0, 'Z' },
     { "slew",		    0, 0, 'x' },
@@ -170,11 +165,6 @@ static void ntpd_usage(void)
     P("				- prohibits the option 'ipv6'\n");
     P("   -6 no  ipv6           Force IPv6 DNS name resolution\n");
     P("				- prohibits the option 'ipv4'\n");
-    P("   -a no  authreq        Require crypto authentication\n");
-    P("				- prohibits the option 'authnoreq'\n");
-    P("   -A no  authnoreq      Do not require crypto authentication\n");
-    P("				- prohibits the option 'authreq'\n");
-    P("   -b no  bcastsync      Allow us to sync to broadcast servers\n");
     P("   -c Str configfile     configuration file name\n");
     P("   -d no  debug-level    Increase output debug message level\n");
     P("				- may appear multiple times\n");
@@ -232,7 +222,6 @@ parse_cmdline_opts(
 	)
 {
 	static bool	parsed = false;
-	bool sawV = false;
 
 	if (parsed)
 	    return;
@@ -354,7 +343,7 @@ parse_cmdline_opts(
 			size_t	len;
 
 			*group++ = '\0'; /* get rid of the ':' */
-			len = group - user;
+			len = (size_t)(group - user);
 			group = estrdup(group);
 			user = erealloc(user, len);
 		}
@@ -365,7 +354,7 @@ parse_cmdline_opts(
 		    long val = atol(argv[ntp_optind]);
 
 		    if (val >= 0)
-			    interface_interval = val;
+			    interface_interval = (int)val;
 		    else {
 			    fprintf(stderr,
 				    "command line interface update interval %ld must not be negative\n",
@@ -378,23 +367,14 @@ parse_cmdline_opts(
 		}
 		break;
 	    case 'V':
-		sawV = true;
 		printf("%s\n", ntpd_version());
-		break;
+		exit(0);
 	    case 'w':
-		wait_sync = strtod(ntp_optarg, NULL);
+		wait_sync = (long)strtod(ntp_optarg, NULL);
 		break;
 	    case 'x':
 		/* defer */
 		break;
-	    case 'y':
-		nofork = true;
-		/* further processed by interception code */
-		break;
-	    case 'Y':
-		nofork = true;
-		/* further processed by interception code */
-		break;
 	    case 'z':
 		/* defer */
 		break;
@@ -417,9 +397,6 @@ parse_cmdline_opts(
 		cmdline_server_count = argc - ntp_optind;
 		cmdline_servers = argv + ntp_optind;
 	}
-
-	if (sawV)
-		exit(0);
 }
 
 #ifdef NO_MAIN_ALLOWED
@@ -549,14 +526,14 @@ ntpdmain(
 		char buf[1024];	/* Secret knowledge of msyslog buf length */
 		char *cp = buf;
 
-		msyslog(LOG_NOTICE, "ntpd %s: Starting", ntpd_version());
+		msyslog(LOG_NOTICE, "%s: Starting", ntpd_version());
 
 		/* Note that every arg has an initial space character */
 		snprintf(cp, sizeof(buf), "Command line:");
 		cp += strlen(cp);
 
 		for (int i = 0; i < saved_argc ; ++i) {
-			snprintf(cp, sizeof(buf) - (cp - buf),
+			snprintf(cp, sizeof(buf) - (size_t)(cp - buf),
 				" %s", saved_argv[i]);
 			cp += strlen(cp);
 		}
@@ -651,14 +628,6 @@ ntpdmain(
 # endif		/* HAVE_WORKING_FORK */
 	}
 
-        /*
-	 * Initialize libsodium and its RNG
-	 */
-	if (sodium_init() < 0) {
-		msyslog(LOG_ERR, "sodium_init() failed");
-		exit(1);
-	}
-
 	/*
 	 * Set up signals we pay attention to locally.
 	 */
@@ -686,7 +655,7 @@ ntpdmain(
 	 *
 	 * Exactly what command-line options are we expecting here?
 	 */
-	INIT_SSL();
+	ssl_init();
 	init_auth();
 	init_util();
 	init_restrict();
@@ -735,14 +704,14 @@ ntpdmain(
 		break;
 	    case 't':
 		{
-		    u_long tkey = (int)atol(ntp_optarg);
+		    u_long tkey = (u_long)atol(ntp_optarg);
 		    if (tkey == 0 || tkey > NTP_MAXKEY) {
 			msyslog(LOG_ERR,
 				"command line trusted key %s is invalid",
 				ntp_optarg);
 			exit(0);
 		    } else {
-			authtrust(tkey, true);
+			authtrust((keyid_t)tkey, true);
 		    }
 	        }
 		break;
@@ -866,6 +835,7 @@ ntpdmain(
 #endif
 	
 	mainloop();
+        /* unreachable, mainloop() never returns */
 	return 1;
 }
 
@@ -924,7 +894,7 @@ static void mainloop(void)
 # ifdef ENABLE_DEBUG_TIMING
 					l_fp dts = pts;
 
-					L_SUB(&dts, &rbuf->recv_time);
+					dts -= rbuf->recv_time;
 					DPRINTF(2, ("processing timestamp delta %s (with prec. fuzz)\n", lfptoa(&dts, 9)));
 					collect_timing(rbuf, "buffer processing delay", 1, &dts);
 					bufcount++;
@@ -940,7 +910,7 @@ static void mainloop(void)
 			}
 # ifdef ENABLE_DEBUG_TIMING
 			get_systime(&tsb);
-			L_SUB(&tsb, &tsa);
+			tsb -= tsa;
 			if (bufcount) {
 				collect_timing(NULL, "processing", bufcount, &tsb);
 				DPRINTF(2, ("processing time for %d buffers %s\n", bufcount, lfptoa(&tsb, 9)));
@@ -958,11 +928,9 @@ static void mainloop(void)
 			reopen_logfile();
 
 			{
-			l_fp snow;
 			time_t tnow;
-			get_systime(&snow);
 			time(&tnow);
-			check_leap_file(false, lfpuint(snow), &tnow);
+			check_leap_file(false, tnow);
 			}
 		}
 
@@ -1042,7 +1010,7 @@ static void catchHUP(int sig)
 static int
 wait_child_sync_if(
 	int	pipe_read_fd,
-	long	wait_sync
+	long	wait_sync1
 	)
 {
 	int	rc;
@@ -1053,12 +1021,12 @@ wait_child_sync_if(
 	fd_set	readset;
 	struct timespec wtimeout;
 
-	if (0 == wait_sync)
+	if (0 == wait_sync1)
 		return 0;
 
 	/* waitsync_fd_to_close used solely by child */
 	close(waitsync_fd_to_close);
-	wait_end_time = time(NULL) + wait_sync;
+	wait_end_time = time(NULL) + wait_sync1;
 	do {
 		cur_time = time(NULL);
 		wait_rem = (wait_end_time > cur_time)
@@ -1100,7 +1068,7 @@ wait_child_sync_if(
 	} while (wait_rem > 0);
 
 	fprintf(stderr, "%s: -w/--wait-sync %ld timed out.\n",
-		progname, wait_sync);
+		progname, wait_sync1);
 	return ETIMEDOUT;
 }
 # endif	/* HAVE_WORKING_FORK */
@@ -1140,7 +1108,7 @@ static void check_minsane()
     else if (servers == 4)
         msyslog(LOG_ERR, "Found 4 servers, suggest minsane of 2");
 
-};
+}
 
 
 /*
@@ -1192,7 +1160,7 @@ library_fatal_error(
  * library_unexpected_error - Handle non fatal errors from our libraries.
  */
 # define MAX_UNEXPECTED_ERRORS 100
-int unexpected_error_cnt = 0;
+static int unexpected_error_cnt = 0;
 static void
 library_unexpected_error(
 	const char *file,
