@@ -66,10 +66,9 @@
  */
 #define _XOPEN_SOURCE 600
 
-#include <config.h>
+#include "config.h"
 #include "ntp.h"
 #include "ntp_types.h"
-#include "ntp_control.h"	/* for CTL_* clocktypes */
 
 /* =====================================================================
  * Get the little JSMN library directly into our guts. Use the 'parent
@@ -207,7 +206,7 @@ typedef struct addrinfo     addrinfoT;
  * We use the same device name scheme as does the NMEA driver; since
  * GPSD supports the same links, we can select devices by a fixed name.
  */
-static const char * s_dev_stem = "/dev/gps";
+#define	DEVICE		"/dev/gps%u"	/* GPS serial device */
 
 /* =====================================================================
  * forward declarations for transfer vector and the vector itself
@@ -255,7 +254,7 @@ struct gpsd_unit {
 	int      unit;
 	int      mode;
 	char    *logname;	/* cached name for log/print */
-	char    * device;	/* device name of unit */
+	char    *device;	/* device name of unit */
 
 	/* current line protocol version */
 	uint32_t proto_version;
@@ -479,6 +478,7 @@ gpsd_start(
 	gpsd_unitT ** uscan    = &s_clock_units;
 
 	struct stat sb;
+        int ret;
 
 	/* check if we can proceed at all or if init failed */
 	if ( ! gpsd_init_check())
@@ -507,8 +507,14 @@ gpsd_start(
 		 * practicable, we will have to read the symlink, if
 		 * any, so we can get the true device file.)
 		 */
-		if (-1 == myasprintf(&up->device, "%s%u",
-				     s_dev_stem, up->unit)) {
+                if ( peer->path ) {
+                    /* use the ntp.conf path name */
+		    ret = myasprintf(&up->device, "%s", peer->path);
+                } else {
+                    ret = myasprintf(&up->device, DEVICE, up->unit);
+                }
+		if (-1 == ret ) {
+                        /* more likely out of RAM */
 			msyslog(LOG_ERR, "%s: clock device name too long",
 				up->logname);
 			goto dev_fail;
@@ -562,7 +568,7 @@ gpsd_start(
 	return true;
 
 dev_fail:
-	/* On failure, remove all UNIT ressources and declare defeat. */
+	/* On failure, remove all UNIT resources and declare defeat. */
 
 	INSIST (up);
 	if (!--up->refcount) {
@@ -660,7 +666,7 @@ gpsd_receive(
 				--pdst;
 			*pdst = '\0';
 			/* process data and reset buffer */
-			up->buflen = pdst - up->buffer;
+			up->buflen = (int)(pdst - up->buffer);
 			gpsd_parse(peer, &rbufp->recv_time);
 			pdst = up->buffer;
 		} else if (pdst != edst) {
@@ -669,7 +675,7 @@ gpsd_receive(
 				*pdst++ = ch;
 		}
 	}
-	up->buflen   = pdst - up->buffer;
+	up->buflen = (int)(pdst - up->buffer);
 	up->tickover = TICKOVER_LOW;
 }
 
@@ -772,13 +778,13 @@ gpsd_control(
 	UNUSED_ARG(out_st);
 
 	if (peer == up->pps_peer) {
-		DTOLFP(pp->fudgetime1, &up->pps_fudge2);
+		up->pps_fudge2 = dtolfp(pp->fudgetime1);
 		if ( ! (pp->sloppyclockflag & CLK_FLAG1))
 			peer->flags &= ~FLAG_PPS;
 	} else {
 		/* save preprocessed fudge times */
-		DTOLFP(pp->fudgetime1, &up->pps_fudge);
-		DTOLFP(pp->fudgetime2, &up->ibt_fudge);
+		up->pps_fudge = dtolfp(pp->fudgetime1);
+		up->ibt_fudge = dtolfp(pp->fudgetime2);
 
 		if (MODE_OP_MODE(up->mode ^ peer->ttl)) {
 			leave_opmode(peer, up->mode);
@@ -799,7 +805,7 @@ timer_primary(
 	int rc;
 
 	/* This is used for timeout handling. Nothing that needs
-	 * sub-second precison happens here, so receive/connect/retry
+	 * sub-second precision happens here, so receive/connect/retry
 	 * timeouts are simply handled by a count down, and then we
 	 * decide what to do by the socket values.
 	 *
@@ -950,7 +956,7 @@ eval_strict(
 	if (up->fl_ibt && up->fl_pps) {
 		/* use TPV reference time + PPS receive time */
 		add_clock_sample(peer, pp, up->ibt_stamp, up->pps_recvt);
-		peer->precision = up->pps_prec;
+		peer->precision = (int8_t)up->pps_prec;
 		/* both packets consumed now... */
 		up->fl_pps = 0;
 		up->fl_ibt = 0;
@@ -973,7 +979,7 @@ eval_pps_secondary(
 	if (up->fl_pps2) {
 		/* feed data */
 		add_clock_sample(peer, pp, up->pps_stamp2, up->pps_recvt2);
-		peer->precision = up->pps_prec;
+		peer->precision = (int8_t)up->pps_prec;
 		/* PPS peer flag logic */
 		up->ppscount2 = min(PPS2_MAXCOUNT, (up->ppscount2 + 2));
 		if ((PPS2_MAXCOUNT == up->ppscount2) &&
@@ -995,7 +1001,7 @@ eval_serial(
 {
 	if (up->fl_ibt) {
 		add_clock_sample(peer, pp, up->ibt_stamp, up->ibt_recvt);
-		peer->precision = up->ibt_prec;
+		peer->precision = (int8_t)up->ibt_prec;
 		/* mark time stamp as burned... */
 		up->fl_ibt = 0;
 		++up->tc_ibt_used;
@@ -1126,7 +1132,7 @@ json_token_skip(
 	if (tid >= 0 && tid < ctx->ntok) {
 		int len = ctx->tok[tid].size;
 		/* For arrays and objects, the size is the number of
-		 * ITEMS in the compound. Thats the number of objects in
+		 * ITEMS in the compound. That's the number of objects in
 		 * the array, and the number of key/value pairs for
 		 * objects. In theory, the key must be a string, and we
 		 * could simply skip one token before skipping the
@@ -1144,6 +1150,8 @@ json_token_skip(
 				tid = json_token_skip(ctx, tid);
 			break;
 			
+                case JSMN_PRIMITIVE:
+                case JSMN_STRING:
 		default:
 			++tid;
 			break;
@@ -1435,7 +1443,8 @@ process_version(
 	clockprocT * const pp = peer->procptr;
 	gpsd_unitT * const up = (gpsd_unitT *)pp->unitptr;
 
-	int    len;
+	size_t len;
+	ssize_t ret;
 	char * buf;
 	const char *revision;
 	const char *release;
@@ -1498,7 +1507,8 @@ process_version(
 	buf = up->buffer;
 	len = strlen(buf);
 	log_data(peer, "send", buf, len);
-	if (len != write(pp->io.fd, buf, len) && (syslogok(pp, up))) {
+	ret = write(pp->io.fd, buf, len);
+	if ( (ret < 0 || (size_t)ret != len) && (syslogok(pp, up))) {
 		/* Note: if the server fails to read our request, the
 		 * resulting data timeout will take care of the
 		 * connection!
@@ -1555,8 +1565,8 @@ process_tpv(
 			DPRINTF(2, ("%s: process_tpv, stamp='%s',"
 				    " recvt='%s' mode=%u\n",
 				    up->logname,
-				    gmprettydate(&up->ibt_stamp),
-				    gmprettydate(&up->ibt_recvt),
+				    gmprettydate(up->ibt_stamp),
+				    gmprettydate(up->ibt_recvt),
 				    gps_mode));
 
 			/* have to use local receive time as substitute
@@ -1565,7 +1575,7 @@ process_tpv(
 			 */
 			up->ibt_local = *rtime;
 			up->ibt_recvt = *rtime;
-			L_SUB(&up->ibt_recvt, &up->ibt_fudge);
+			up->ibt_recvt -= up->ibt_fudge;
 			up->fl_ibt = -1;
 		} else {
 			++up->tc_breply;
@@ -1605,7 +1615,7 @@ process_pps(
 	++up->tc_pps_recv;
 
 	/* Bail out if there's indication that time sync is bad or
-	 * if we're explicitely requested to ignore PPS data.
+	 * if we're explicitly requested to ignore PPS data.
 	 */
 	if (up->fl_nosync)
 		return;
@@ -1634,31 +1644,30 @@ process_pps(
 	/* Try to read the precision field from the PPS record. If it's
 	 * not there, take the precision from the serial data.
 	 */
-	xlog2 = json_object_lookup_int_default(
+	xlog2 = (int)json_object_lookup_int_default(
 			jctx, 0, "precision", up->ibt_prec);
 	up->pps_prec = clamped_precision(xlog2);
 	
 	/* Get fudged receive times for primary & secondary unit */
 	up->pps_recvt = up->pps_recvt2;
-	L_SUB(&up->pps_recvt , &up->pps_fudge );
-	L_SUB(&up->pps_recvt2, &up->pps_fudge2);
+	up->pps_recvt -= up->pps_fudge;
+	up->pps_recvt2 -= up->pps_fudge2;
 	pp->lastrec = up->pps_recvt;
 
 	/* Map to nearest full second as reference time stamp for the
 	 * primary channel. Sanity checks are done in evaluation step.
 	 */
 	up->pps_stamp = up->pps_recvt;
-	L_ADDUF(&up->pps_stamp, 0x80000000u);
+	up->pps_stamp += 0x80000000u;
 	setlfpfrac(up->pps_stamp, 0);
 
 	if (NULL != up->pps_peer)
-		save_ltc(up->pps_peer->procptr,
-			 gmprettydate(&up->pps_stamp2));
+		save_ltc(up->pps_peer->procptr, gmprettydate(up->pps_stamp2));
 	DPRINTF(2, ("%s: PPS record processed,"
 		    " stamp='%s', recvt='%s'\n",
 		    up->logname,
-		    gmprettydate(&up->pps_stamp2),
-		    gmprettydate(&up->pps_recvt2)));
+		    gmprettydate(up->pps_stamp2),
+		    gmprettydate(up->pps_recvt2)));
 	
 	up->fl_pps  = (0 != (pp->sloppyclockflag & CLK_FLAG2)) - 1;
 	up->fl_pps2 = -1;
@@ -1696,16 +1705,16 @@ process_toff(
 	if ( ! get_binary_time(&up->ibt_stamp, jctx,
 			       "real_sec", "real_nsec", 1))
 			goto fail;
-	L_SUB(&up->ibt_recvt, &up->ibt_fudge);
+	up->ibt_recvt -= up->ibt_fudge;
 	up->ibt_local = *rtime;
 	up->fl_ibt    = -1;
 
-	save_ltc(pp, gmprettydate(&up->ibt_stamp));
+	save_ltc(pp, gmprettydate(up->ibt_stamp));
 	DPRINTF(2, ("%s: TOFF record processed,"
 		    " stamp='%s', recvt='%s'\n",
 		    up->logname,
-		    gmprettydate(&up->ibt_stamp),
-		    gmprettydate(&up->ibt_recvt)));
+		    gmprettydate(up->ibt_stamp),
+		    gmprettydate(up->ibt_recvt)));
 	return;
 
   fail:
@@ -1733,7 +1742,8 @@ gpsd_parse(
 	/* See if we can grab anything potentially useful. JSMN does not
 	 * need a trailing NUL, but it needs the number of bytes to
 	 * process. */
-	if (!json_parse_record(&up->json_parse, up->buffer, up->buflen)) {
+	if (!json_parse_record(&up->json_parse, up->buffer,
+                               (size_t)up->buflen)) {
 		++up->tc_breply;
 		return;
 	}
@@ -1772,7 +1782,7 @@ gpsd_parse(
 	if (up->fl_pps && up->fl_ibt) {
 		l_fp diff;
 		diff = up->ibt_local;
-		L_SUB(&diff, &up->pps_local);
+		diff -= up->pps_local;
 		if (lfpsint(diff) > 0)
 			up->fl_pps = 0; /* pps too old */
 		else if (lfpsint(diff) < 0)
