@@ -5,14 +5,14 @@
  * SPDX-License-Identifier: BSD-4-clause
  */
 
-#include <config.h>
+#include "config.h"
 #include "ntp.h"
 #include "ntpd.h"
 #include "ntp_io.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
-#include "ntp_control.h"	/* for CTL_* clocktypes */
 #include "ntp_calendar.h"
+#include "timespecops.h"
 
 #include <stdio.h>
 #include <ctype.h>
@@ -381,8 +381,8 @@ struct	refclock refclock_jupiter = {
 	jupiter_shutdown,	/* shut down driver */
 	jupiter_poll,		/* transmit poll message */
 	jupiter_control,	/* (clock control) */
-	noentry,		/* (clock init) */
-	noentry			/* timer - not used */
+	NULL,			/* (clock init) */
+	NULL			/* timer - not used */
 };
 
 /*
@@ -613,7 +613,7 @@ jupiter_pps(struct instance *instance)
 	pps_info_t pps_info;
 	struct timespec timeout, ts;
 	double dtemp;
-	l_fp tstmp;
+	l_fp tstmp = 0;
 
 	/*
 	 * Convert the timespec nanoseconds field to ntp l_fp units.
@@ -644,7 +644,7 @@ jupiter_pps(struct instance *instance)
 	instance->ts = ts;
 
 	setlfpuint(tstmp, (uint32_t)ts.tv_sec + JAN_1970);
-	dtemp = ts.tv_nsec * FRAC / 1e9;
+	dtemp = ts.tv_nsec * FRAC * S_PER_NS;
 	setlfpfrac(tstmp, (uint32_t)dtemp);
 	instance->peer->procptr->lastrec = tstmp;
 	return false;
@@ -714,10 +714,10 @@ jupiter_control(
 	pp = peer->procptr;
 	instance = pp->unitptr;
 
-	DTOLFP(pp->fudgetime2, &instance->limit);
+	instance->limit = dtolfp(pp->fudgetime2);
 	/* Force positive value. */
-	if (L_ISNEG(&instance->limit))
-		L_NEG(&instance->limit);
+	if (L_ISNEG(instance->limit))
+		L_NEG(instance->limit);
 
 #ifdef HAVE_PPSAPI
 	instance->assert = !(pp->sloppyclockflag & CLK_FLAG3);
@@ -771,7 +771,7 @@ jupiter_receive(struct recvbuf *rbufp)
 
 	/* Append to input buffer */
 	memcpy((uint8_t *)instance->sbuf + instance->ssize, bp, bpcnt);
-	instance->ssize += bpcnt;
+	instance->ssize += (ssize_t)bpcnt;
 
 	/* While there's at least a header and we parse an intact message */
 	while (instance->ssize > (int)sizeof(*hp) && (cc = jupiter_recv(instance)) > 0) {
@@ -819,8 +819,7 @@ jupiter_receive(struct recvbuf *rbufp)
 			 * (i.e. before limit, a.k.a. fudgetime2) in
 			 * the second.
 			 */
-			L_SUB(&tstamp, &pp->lastrec);
-			if (!L_ISGEQ(&tstamp, &instance->limit))
+			if (tstamp - pp->lastrec < instance->limit)
 				bumplfpuint(pp->lastrec, 1);
 
 			/* Parse timecode (even when there's no pps) */
@@ -840,8 +839,7 @@ jupiter_receive(struct recvbuf *rbufp)
 				break;
 
 			/* Add the new sample to a median filter */
-			setlfpuint(tstamp, JAN_1970 + (uint32_t)last_timecode);
-			setlfpfrac(tstamp, 0);
+			tstamp = lfpinit(JAN_1970 + (uint32_t)last_timecode, 0);
 
 			refclock_process_offset(pp, tstamp, pp->lastrec, pp->fudgetime1);
 
@@ -932,7 +930,8 @@ jupiter_receive(struct recvbuf *rbufp)
 			fprintf(stderr, "jupiter_recv: negative ssize!\n");
 			abort();
 		} else if (instance->ssize > 0)
-			memcpy(instance->sbuf, (uint8_t *)instance->sbuf + cc, instance->ssize);
+			memcpy(instance->sbuf, (uint8_t *)instance->sbuf + cc,
+                               (size_t) instance->ssize);
 	}
 }
 
@@ -1315,7 +1314,7 @@ jupiter_recv(struct instance *instance)
 		*/
 		/* Shuffle data to front of input buffer */
 		if (n > 0)
-			memcpy(sp, bp, n);
+			memcpy(sp, bp, (size_t)n);
 		size = n;
 		instance->ssize = size;
 		if (size < cc || hp->sync != JUPITER_SYNC)
