@@ -13,13 +13,13 @@
  */
 
 
-#include <config.h>
+#include "config.h"
 #include "ntpd.h"
 #include "ntp_io.h"
-#include "ntp_control.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
 #include "ntp_calendar.h"
+#include "timespecops.h"
 
 #include <stdio.h>
 #include <ctype.h>
@@ -36,11 +36,6 @@
  * MX 4200D, MX 9212, MX 9012R, MX 9112 will be supported by this code.
  */
 
-/*
- * Check this every time you edit the code!
- */
-#define YEAR_LAST_MODIFIED 2000
-
 /*
  * GPS Definitions
  */
@@ -110,7 +105,7 @@
  */
 struct mx4200unit {
 	u_int  pollcnt;			/* poll message counter */
-	u_int  polled;			/* Hand in a time sample? */
+	bool   polled;			/* Hand in a time sample? */
 	u_int  lastserial;		/* last pps serial number */
 	double avg_lat;			/* average latitude */
 	double avg_lon;			/* average longitude */
@@ -129,6 +124,7 @@ struct mx4200unit {
 };
 
 static char pmvxg[] = "PMVXG";
+static int year_last_modified;
 
 /*
  * Function prototypes
@@ -160,9 +156,9 @@ struct	refclock refclock_magnavox = {
 	mx4200_start,		/* start up driver */
 	mx4200_shutdown,	/* shut down driver */
 	mx4200_poll,		/* transmit poll message */
-	noentry,		/* not used (old mx4200_control) */
-	noentry,		/* initialize driver (not used) */
-	noentry			/* timer - not used */
+	NULL,			/* not used (old mx4200_control) */
+	NULL,			/* initialize driver (not used) */
+	NULL			/* timer - not used */
 };
 
 
@@ -216,6 +212,14 @@ mx4200_start(
 	pp->clockdesc = DESCRIPTION;
 	memcpy((char *)&pp->refid, REFID, REFIDLEN);
 	peer->sstclktype = CTL_SST_TS_LF;
+	/* 
+	 * __DATE__ is in a format like "Jan 2 2017" or possibly "???
+	 * ?? ????".  Thus it is guaranteed that there will be a
+	 * rightmost space just before the date.  It's OK if atoi()
+	 * barfs on ???? because this is only used in a sanity check
+	 * where that will fail positive.
+	 */
+	year_last_modified = atoi(strrchr(__DATE__, ' ') + 1);
 
 	/* Ensure the receiver is properly configured */
 	return mx4200_config(peer);
@@ -277,7 +281,7 @@ mx4200_config(
 		up->moving   = false;	/* Static Installation */
 	}
 	up->pollcnt     	= 2;
-	up->polled      	= 0;
+	up->polled      	= false;
 	up->known       	= false;
 	up->avg_lat     	= 0.0;
 	up->avg_lon     	= 0.0;
@@ -609,7 +613,7 @@ mx4200_poll(
 	 * polled every 64 seconds. Ask mx4200_receive to hand in
 	 * a timestamp.
 	 */
-	up->polled = 1;
+	up->polled = true;
 	pp->polls++;
 
 	/*
@@ -857,7 +861,7 @@ mx4200_receive(
 		mx4200_debug(peer, "mx4200_receive: process time: ");
 		mx4200_debug(peer, "%4d-%03d %02d:%02d:%02d at %s, %.6f\n",
 		    pp->year, pp->day, pp->hour, pp->minute, pp->second,
-		    prettydate(&pp->lastrec), pp->offset);
+		    prettydate(pp->lastrec), pp->offset);
 		pp->lastref = pp->lastrec;
 		refclock_receive(peer);
 
@@ -865,7 +869,7 @@ mx4200_receive(
 		 * We have succeeded in answering the poll.
 		 * Turn off the flag and return
 		 */
-		up->polled = 0;
+		up->polled = false;
 		break;
 
 	/*
@@ -991,7 +995,7 @@ mx4200_parse_t(
 	 * (Certainly can't be any year before this code was last altered!)
 	 */
 	if (day_of_month > 31 || month > 12 ||
-	    day_of_month <  1 || month <  1 || year < YEAR_LAST_MODIFIED) {
+	    day_of_month <  1 || month <  1 || year < year_last_modified) {
 		mx4200_debug(peer,
 		    "mx4200_parse_t: bad date (%4d-%02d-%02d)\n",
 		    year, month, day_of_month);
@@ -1519,11 +1523,7 @@ mx4200_pps(
 	/*
 	 * Return the timestamp in pp->lastrec
 	 */
-
-	setlfpuint(pp->lastrec, up->pps_i.assert_timestamp.tv_sec +
-		   (uint32_t) JAN_1970);
-	setlfpfrac(pp->lastrec, ((double)(up->pps_i.assert_timestamp.tv_nsec) *
-				 4.2949672960) + 0.5);
+	pp->lastrec = tspec_stamp_to_lfp(up->pps_i.assert_timestamp);
 
 	return false;
 }
@@ -1562,23 +1562,21 @@ mx4200_send(struct peer *peer, char *fmt, ...)
 {
 	struct refclockproc *pp;
 
-	register char *cp;
 	register int n, m;
 	va_list ap;
-	char buf[1024];
+	char buf1[1024];
+	char buf[sizeof(buf1)  + 10];
 	uint8_t ck;
 
 	va_start(ap, fmt);
 
 	pp = peer->procptr;
 
-	cp = buf;
-	*cp++ = '$';
-	n = vsnprintf(cp, sizeof(buf) - 1, fmt, ap);
-	ck = mx4200_cksum(cp, n);
-	cp += n;
-	++n;
-	n += snprintf(cp, sizeof(buf) - n - 5, "*%02X\r\n", ck);
+	vsnprintf(buf1, sizeof(buf1) - 1, fmt, ap);
+        buf1[sizeof(buf1) - 1 ] = '\0';
+	ck = mx4200_cksum(buf1, strlen(buf1));
+        /* buf can never overrun */
+	n = snprintf(buf, sizeof(buf) - 1, "$%1024s*%02X\r\n", buf1, ck);
 
 	m = write(pp->io.fd, buf, (unsigned)n);
 	if (m < 0)
