@@ -8,7 +8,6 @@
 #include "ntp_io.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
-#include "ntp_control.h"	/* for CTL_* clocktypes */
 
 #include <stdio.h>
 #include <ctype.h>
@@ -136,8 +135,8 @@
 #define NAME		"MODEM"	/* shortname */
 #define DESCRIPTION	"Automated Computer Time Service" /* WRU */
 #define REFID		"NONE"	/* default reference ID */
-#define MSGCNT		20	/* max message count */
-#define	MAXPHONE	10	/* max number of phone numbers */
+/* #define MSGCNT	20	* max message count UNUSED */
+/* #define MAXPHONE	10	* max number of phone numbers UNUSED */
 
 /*
  * Calling program modes (mode)
@@ -175,8 +174,8 @@
  * V1	return result codes as English words
  * Y1	enable long-space disconnect
  */
-const char def_modem_setup[] = "ATB1&C0&D2E0L1M1Q0V1Y1";
-const char *modem_setup = def_modem_setup;
+static const char def_modem_setup[] = "ATB1&C0&D2E0L1M1Q0V1Y1";
+static const char *modem_setup = def_modem_setup;
 
 /*
  * Timeouts (all in seconds)
@@ -232,8 +231,8 @@ struct refclock refclock_modem = {
 	modem_start,		/* start up driver */
 	modem_shutdown,		/* shut down driver */
 	modem_poll,		/* transmit poll message */
-	noentry,		/* control - not used */
-	noentry,		/* init - not used */
+	NULL,			/* control - not used */
+	NULL,			/* init - not used */
 	modem_timer		/* housekeeping timer */
 };
 
@@ -330,7 +329,7 @@ modem_receive(
 	peer = rbufp->recv_peer;
 	pp = peer->procptr;
 	up = pp->unitptr;
-	octets = sizeof(up->buf) - (up->bufptr - up->buf);
+	octets = sizeof(up->buf) - (size_t)(up->bufptr - up->buf);
 	refclock_gtraw(rbufp, tbuf, octets, &pp->lastrec);
 	for (tptr = tbuf; *tptr != '\0'; tptr++) {
 		if (*tptr == LF) {
@@ -422,7 +421,7 @@ modem_message(
 	/*
 	 * We are waiting for the CONNECT response to the dial
 	 * command. When this happens, listen for timecodes. If
-	 * somthing other than CONNECT is received, like BUSY
+	 * something other than CONNECT is received, like BUSY
 	 * or NO CARRIER, abort the call.
 	 */
 	case S_CONNECT:
@@ -469,7 +468,7 @@ modem_timeout(
 	struct modemunit *up;
 	struct refclockproc *pp;
 	int	fd;
-	int	rc;
+	ssize_t	rc;
 	char	device[20];
 	char	lockfile[128], pidbuf[8];
 
@@ -705,7 +704,7 @@ modem_timer(
 	UNUSED_ARG(unit);
 
 	/*
-	 * This routine implments a timeout which runs for a programmed
+	 * This routine implements a timeout which runs for a programmed
 	 * interval. The counter is initialized by the state machine and
 	 * counts down to zero. Upon reaching zero, the state machine is
 	 * called. If flag1 is set while timer is zero, force a call.
@@ -720,7 +719,7 @@ modem_timer(
 	} else {
 		up->timer--;
 		if (up->timer == 0)
-			modem_timeout(peer, up->state);
+			modem_timeout(peer, (teModemState)up->state);
 	}
 }
 
@@ -910,7 +909,7 @@ modem_timecode(
 		return;
 
 	strlcpy(pp->a_lastcode, str, sizeof(pp->a_lastcode));
-	pp->lencode = strlen(pp->a_lastcode);
+	pp->lencode = (int)strlen(pp->a_lastcode);
 	if (!refclock_process(pp)) {
 		refclock_report(peer, CEVNT_BADTIME);
 		return;
