@@ -20,7 +20,6 @@
 
 #include "ntpd.h"
 #include "ntp_io.h"
-#include "ntp_control.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
 
@@ -43,8 +42,10 @@
 #define NEOCLOCK4X_FIRMWARE                NEOCLOCK4X_FIRMWARE_VERSION_A
 #endif
 
+#if defined(NEOCLOCK4X_FIRMWARE)
 /* at this time only firmware version A is known */
-#define NEOCLOCK4X_FIRMWARE_VERSION_A      'A'
+# define NEOCLOCK4X_FIRMWARE_VERSION_A      'A'
+#endif
 
 #define NEOCLOCK4X_TIMECODELEN 37
 
@@ -57,7 +58,7 @@
 #define NEOCLOCK4X_OFFSET_MINUTE           20
 #define NEOCLOCK4X_OFFSET_SECOND           22
 #define NEOCLOCK4X_OFFSET_HSEC             24
-#define NEOCLOCK4X_OFFSET_DOW              26
+/* #define NEOCLOCK4X_OFFSET_DOW              26  UNUSED */
 #define NEOCLOCK4X_OFFSET_TIMESOURCE       28
 #define NEOCLOCK4X_OFFSET_DSTSTATUS        29
 #define NEOCLOCK4X_OFFSET_QUARZSTATUS      30
@@ -116,8 +117,8 @@ struct refclock refclock_neoclock4x = {
   neoclock4x_shutdown,	/* shut down driver */
   neoclock4x_poll,	/* transmit poll message */
   neoclock4x_control,	/* device control */
-  noentry,		/* initialize driver (not used) */
-  noentry,		/* tiner - not used */
+  NULL,			/* initialize driver (not used) */
+  NULL,			/* tiner - not used */
 };
 
 static bool
@@ -240,7 +241,7 @@ neoclock4x_start(int unit,
    * no fudge time is given by user!
    * use 169.583333 ms to compensate the serial line delay
    * formula is:
-   * 2400 Baud / 11 bit = 218.18 charaters per second
+   * 2400 Baud / 11 bit = 218.18 characters per second
    *  (NeoClock4X timecode len)
    */
   pp->fudgetime1 = (NEOCLOCK4X_TIMECODELEN * 11) / 2400.0;
@@ -253,7 +254,7 @@ neoclock4x_start(int unit,
   peer->sstclktype = CTL_SST_TS_UHF;
 
   up->leap_status = 0;
-  up->unit = unit;
+  up->unit = (short)unit;
   strlcpy(up->firmware, "?", sizeof(up->firmware));
   up->firmwaretag = '?';
   strlcpy(up->serial, "?", sizeof(up->serial));
@@ -564,7 +565,7 @@ neoclock4x_receive(struct recvbuf *rbufp)
   up->utc_hour   = pp->hour;
   up->utc_minute = pp->minute;
   up->utc_second = pp->second;
-  up->utc_msec   = pp->nsec/NSEC_TO_MILLI;
+  up->utc_msec   = (int)pp->nsec/NSEC_TO_MILLI;
 
   if(!refclock_process(pp))
     {
@@ -917,7 +918,7 @@ neol_query_firmware(int fd,
 		  tmpbuf[len++] = ' ';
 		  tmpbuf[len++] = '/';
 		  tmpbuf[len++] = ' ';
-		  lastsearch = len;
+		  lastsearch = (int)len;
 		}
 	      last_c_was_crlf = true;
 	    }
@@ -1029,7 +1030,7 @@ neol_check_firmware(int unit,
  *
  * 2006/01/11 cjh
  * Revision 1.15
- * - remove some unsued #ifdefs
+ * - remove some unused #ifdefs
  * - fix nsec calculation, closes #499
  *
  * 2009/12/04 cjh
