@@ -18,7 +18,7 @@
 
 #define NMEA_WRITE_SUPPORT 0 /* no write support at the moment */
 
-#include <config.h>
+#include "config.h"
 #include "ntp_types.h"
 #include <sys/stat.h>
 #include <stdio.h>
@@ -31,7 +31,6 @@
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
 #include "ntp_calendar.h"
-#include "ntp_control.h"	/* for CTL_* clocktypes */
 #include "timespecops.h"
 
 #ifdef HAVE_PPSAPI
@@ -87,7 +86,7 @@
 #define NMEA_DATETRUST_MASK	0x02000000U
 
 #define NMEA_PROTO_IDLEN	5	/* tag name must be at least 5 chars */
-#define NMEA_PROTO_MINLEN	6	/* min chars in sentence, excluding CS */
+/* #define NMEA_PROTO_MINLEN 6 * min chars in sentence, excluding CS UNUSED */
 #define NMEA_PROTO_MAXLEN	80	/* max chars in sentence, excluding CS */
 #define NMEA_PROTO_FIELDS	32	/* not official; limit on fields per record */
 
@@ -140,28 +139,30 @@
  * Definitions
  */
 #define	DEVICE		"/dev/gps%d"	/* GPS serial device */
-#define	PPSDEV		"/dev/gpspps%d"	/* PPSAPI device override */
+#ifdef HAVE_PPSAPI
+# define	PPSDEV		"/dev/gpspps%d"	/* PPSAPI device override */
+# define	PPS_PRECISION	(-20)		/* precision assumed (~ 1 us) */
+# ifndef O_NOCTTY
+#  define M_NOCTTY	0
+# else
+#  define M_NOCTTY	O_NOCTTY
+# endif
+# ifndef O_NONBLOCK
+#  define M_NONBLOCK	0
+# else
+#  define M_NONBLOCK	O_NONBLOCK
+# endif
+# define PPSOPENMODE	(O_RDWR | M_NOCTTY | M_NONBLOCK)
+#endif
 #ifdef ENABLE_CLASSIC_MODE
 #define	SPEED232	B4800		/* uart speed (4800 bps) */
 #else
 #define	SPEED232	B9600		/* uart speed (9600 bps) */
 #endif
 #define	PRECISION	(-9)		/* precision assumed (about 2 ms) */
-#define	PPS_PRECISION	(-20)		/* precision assumed (about 1 us) */
 #define	REFID		"GPS\0"		/* reference id */
 #define	NAME		"NMEA"		/* shortname */
 #define	DESCRIPTION	"NMEA GPS Clock" /* who we are */
-#ifndef O_NOCTTY
-#define M_NOCTTY	0
-#else
-#define M_NOCTTY	O_NOCTTY
-#endif
-#ifndef O_NONBLOCK
-#define M_NONBLOCK	0
-#else
-#define M_NONBLOCK	O_NONBLOCK
-#endif
-#define PPSOPENMODE	(O_RDWR | M_NOCTTY | M_NONBLOCK)
 
 /* NMEA sentence array indexes for those we use */
 #define NMEA_GPRMC	0	/* recommended min. nav. */
@@ -290,7 +291,7 @@ static	void	nmea_control	(int, const struct refclockstat *,
 				 struct refclockstat *, struct peer *);
 #define		NMEA_CONTROL	nmea_control
 #else
-#define		NMEA_CONTROL	noentry
+#define		NMEA_CONTROL	NULL
 #endif /* HAVE_PPSAPI */
 static	void	nmea_timer	(int, struct peer *);
 
@@ -318,7 +319,7 @@ static void     save_ltc        (struct refclockproc * const, const char * const
 				 size_t);
 
 /*
- * If we want the driver to ouput sentences, too: re-enable the send
+ * If we want the driver to output sentences, too: re-enable the send
  * support functions by defining NMEA_WRITE_SUPPORT to non-zero...
  */
 #if NMEA_WRITE_SUPPORT
@@ -411,7 +412,7 @@ nmea_start(
 	switch (rate) {
 	case 0:
 	case 4800:
-		baudrate = SPEED232;
+		baudrate = 4800;
 		baudtext = "4800";
 		break;
 	case 1:
@@ -445,7 +446,11 @@ nmea_start(
 #endif
 	default:
 		baudrate = SPEED232;
+#ifdef ENABLE_CLASSIC_MODE
 		baudtext = "4800 (fallback)";
+#else
+		baudtext = "9600 (fallback)";
+#endif
 		break;
 	}
 
@@ -553,7 +558,8 @@ nmea_control(
 	/* Light up the PPSAPI interface if not yet attempted. */
 	if ((CLK_FLAG1 & pp->sloppyclockflag) && !up->ppsapi_tried) {
 		up->ppsapi_tried = true;
-		devlen = snprintf(device, sizeof(device), PPSDEV, unit);
+                /* FIXME: snprintf() can return negative on error */
+		devlen = (size_t)snprintf(device, sizeof(device), PPSDEV, unit);
 		if (devlen < sizeof(device)) {
 		    up->ppsapi_fd = open(peer->ppspath ? peer->ppspath : device,
 					 PPSOPENMODE, S_IRUSR | S_IWUSR);
@@ -720,8 +726,8 @@ refclock_ppsrelate(
 	/* get delta between receive time and PPS time */
 	pp_stamp = tspec_stamp_to_lfp(timeout);
 	pp_delta = *rd_stamp;
-	L_SUB(&pp_delta, &pp_stamp);
-	LFPTOD(&pp_delta, delta);
+	pp_delta -= pp_stamp;
+	delta = lfptod(pp_delta);
 	delta += pp_fudge - *rd_fudge;
 	if (fabs(delta) > 1.5)
 		return PPS_RELATE_NONE; /* PPS timeout control */
@@ -743,8 +749,8 @@ refclock_ppsrelate(
 
 	/* check against reftime if PPS PLL can be used */
 	pp_delta = *reftime;
-	L_SUB(&pp_delta, &pp_stamp);
-	LFPTOD(&pp_delta, delta);
+	pp_delta-= pp_stamp;
+	delta = lfptod(pp_delta);
 	delta += pp_fudge;
 	if (fabs(delta) > 0.45)
 		return PPS_RELATE_EDGE; /* cannot PLL with PPS code */
@@ -1002,7 +1008,7 @@ nmea_receive(
 		checkres = -1;
 
 	if (checkres != -1) {
-		save_ltc(pp, rd_lastcode, rd_lencode);
+		save_ltc(pp, rd_lastcode, (size_t)rd_lencode);
 		refclock_report(peer, checkres);
 		return;
 	}
@@ -1026,7 +1032,7 @@ nmea_receive(
 	 * Discard sentence if reference time did not change.
 	 */
 	rd_reftime = eval_gps_time(peer, &date, &tofs, &rd_timestamp);
-	if (L_ISEQU(&up->last_reftime, &rd_reftime)) {
+	if (up->last_reftime == rd_reftime) {
 		/* Do not touch pp->a_lastcode on purpose! */
 		up->tally.filtered++;
 		return;
@@ -1039,7 +1045,7 @@ nmea_receive(
 
 	/* Data will be accepted. Update stats & log data. */
 	up->tally.accepted++;
-	save_ltc(pp, rd_lastcode, rd_lencode);
+	save_ltc(pp, rd_lastcode, (size_t)rd_lencode);
 	pp->lastrec = rd_timestamp;
 
 #ifdef HAVE_PPSAPI
@@ -1857,7 +1863,7 @@ eval_gps_time(
 	/* - check if we should log a GPS epoch warp */
 	weeks = (adj_day - gps_day) / 7;
 	if (weeks != up->epoch_warp) {
-		up->epoch_warp = weeks;
+		up->epoch_warp = (short)weeks;
 		LOGIF(CLOCKINFO, (LOG_INFO,
 				  "%s Changed GPS epoch warp to %d weeks",
 				  refclock_name(peer), weeks));
