@@ -57,7 +57,6 @@
 
 #include "ntpd.h"
 #include "ntp_io.h"
-#include "ntp_control.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
 
@@ -119,16 +118,18 @@
  * 	TRIMBLE_UTC_TIME set   and TRIMBLE_LEAP_PENDING set: INSERT leap
  */
 
-#define TRIMBLE_LEAP_INPROGRESS 0x08 /* This is the leap flag			*/
-#define TRIMBLE_LEAP_WARNING    0x04 /* GPS Leap Warning (see ICD-200) */
+/* #define TRIMBLE_LEAP_INPROGRESS 0x08 * This is the leap flag	UNUSED */
+/* #define TRIMBLE_LEAP_WARNING    0x04 * GPS Leap Warning (ICD-200) UNUSED */
 #define TRIMBLE_LEAP_PENDING    0x02 /* Leap Pending (24 hours)		*/
 #define TRIMBLE_UTC_TIME        0x01 /* UTC time available				*/
 
 #define mb(_X_) (up->rpt_buf[(_X_ + 1)]) /* shortcut for buffer access	*/
 
 /* Conversion Definitions */
-#define GPS_PI 		(3.1415926535898)
-#define	R2D		(180.0/GPS_PI)
+#ifdef DEBUG
+# define GPS_PI 	(3.1415926535898)
+# define R2D		(180.0/GPS_PI)
+#endif
 
 /*
  * Structure for build data packets for send (thunderbolt uses it only)
@@ -184,7 +185,7 @@ static  void	init_acutime		(int fd);
 
 
 /* Table to get from month to day of the year */
-const int days_of_year [12] = {
+static const int days_of_year [12] = {
 	0,  31,  59,  90, 120, 151, 181, 212, 243, 273, 304, 334
 };
 
@@ -205,9 +206,9 @@ struct refclock refclock_trimble = {
 	trimble_start,		/* start up driver */
 	trimble_shutdown,	/* shut down driver */
 	trimble_poll,		/* transmit poll message */
-	noentry,		/* control - not used  */
-	noentry,		/* initialize driver (not used) */
-	noentry			/* timer - not used */
+	NULL,			/* control - not used  */
+	NULL,			/* initialize driver (not used) */
+	NULL			/* timer - not used */
 };
 
 int day_of_year (char *dt);
@@ -220,9 +221,9 @@ int day_of_year (char *dt);
 #define CLK_PRAECIS	1	/* Endrun Technologies Praecis */
 #define CLK_THUNDERBOLT	2	/* Trimble Thunderbolt GPS Receiver */
 #define CLK_ACUTIME     3	/* Trimble Acutime Gold */
-#define CLK_ACUTIMEB    4	/* Trimble Actutime Gold Port B */
+/* #define CLK_ACUTIMEB 4	* Trimble Actutime Gold Port B UNUSED */
 
-bool praecis_msg;
+static bool praecis_msg;
 static void praecis_parse(struct recvbuf *rbufp, struct peer *peer);
 
 /* These routines are for sending packets to the Thunderbolt receiver
@@ -297,7 +298,7 @@ sendetx (
 	int fd
 	)
 {
-	int result;
+	ssize_t result;
 	
 	*(buffer->data+buffer->size++) = DLE;
 	*(buffer->data+buffer->size++) = ETX;
@@ -587,13 +588,14 @@ TSIP_decode (
 		/* 
 		 * Superpackets
 		 */
+		int GPS_UTC_Offset;
+
 		event = (unsigned short) (getint((uint8_t *) &mb(1)) & 0xffff);
 		if (!((pp->sloppyclockflag & CLK_FLAG2) || event)) 
 			/* Ignore Packet */
 			return 0;	   
 	
 		switch (mb(0) & 0xff) {
-			int GPS_UTC_Offset;
 
 		    case PACKET_8F0B: 
 
@@ -639,9 +641,9 @@ TSIP_decode (
 			pp->nsec = (long) (secfrac * 1000000000); 
 
 			secint %= 86400;    /* Only care about today */
-			pp->hour = secint / 3600;
+			pp->hour = (int)(secint / 3600);
 			secint %= 3600;
-			pp->minute = secint / 60;
+			pp->minute = (int)(secint / 60);
 			secint %= 60;
 			pp->second = secint % 60;
 		
@@ -1057,7 +1059,7 @@ trimble_receive (
 #ifdef DEBUG
 	if (debug)
 		printf("trimble_receive: unit %d: %s\n",
-		       up->unit, prettydate(&pp->lastrec));
+		       up->unit, prettydate(pp->lastrec));
 #endif
 	pp->lastref = pp->lastrec;
 	refclock_receive(peer);
@@ -1116,7 +1118,7 @@ praecis_parse (
 	)
 {
 	static char buf[100];
-	static int p = 0;
+	static size_t p = 0;
 	struct refclockproc *pp;
 
 	pp = peer->procptr;
