@@ -3,7 +3,7 @@
  *	Receiver Version 3.0C - tested plain, with CLKLDISC
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <ctype.h>
 
@@ -12,7 +12,6 @@
 #include "ntp_io.h"
 #include "ntp_refclock.h"
 #include "ntp_stdlib.h"
-#include "ntp_control.h"	/* for CTL_* clocktypes */
 
 /* This should be an atom clock but those are very hard to build.
  *
@@ -112,18 +111,18 @@
  */
 enum true_event	{e_Init, e_Huh, e_F18, e_F50, e_F51, e_Satellite,
 		 e_Poll, e_Location, e_TS, e_Max};
-const char *events[] = {"Init", "Huh", "F18", "F50", "F51", "Satellite",
+static const char *events[] = {"Init", "Huh", "F18", "F50", "F51", "Satellite",
 			"Poll", "Location", "TS"};
 #define eventStr(x) (((int)x<(int)e_Max) ? events[(int)x] : "?")
 
 enum true_state	{s_Base, s_InqTM, s_InqTCU, s_InqGOES,
 		 s_Init, s_F18, s_F50, s_Start, s_Auto, s_Max};
-const char *states[] = {"Base", "InqTM", "InqTCU", "InqGOES",
+static const char *states[] = {"Base", "InqTM", "InqTCU", "InqGOES",
 			"Init", "F18", "F50", "Start", "Auto"};
 #define stateStr(x) (((int)x<(int)s_Max) ? states[(int)x] : "?")
 
 enum true_type	{t_unknown, t_goes, t_tm, t_tcu, t_omega, t_tl3, t_Max};
-const char *types[] = {"unknown", "goes", "tm", "tcu", "omega", "tl3"};
+static const char *types[] = {"unknown", "goes", "tm", "tcu", "omega", "tl3"};
 #define typeStr(x) (((int)x<(int)t_Max) ? types[(int)x] : "?")
 
 /*
@@ -164,9 +163,9 @@ struct	refclock refclock_true = {
 	true_start,		/* start up driver */
 	true_shutdown,		/* shut down driver */
 	true_poll,		/* transmit poll message */
-	noentry,		/* not used (old true_control) */
-	noentry,		/* initialize driver (not used) */
-	noentry			/* timer - not used */
+	NULL,			/* not used (old true_control) */
+	NULL,			/* initialize driver (not used) */
+	NULL			/* timer - not used */
 };
 
 
@@ -332,7 +331,7 @@ true_receive(
 	/*
 	 * Read clock output.  Automatically handles CLKLDISC.
 	 */
-	rd_lencode = refclock_gtlin(rbufp, rd_lastcode, BMAX, &rd_tmp);
+	rd_lencode = (u_short)refclock_gtlin(rbufp, rd_lastcode, BMAX, &rd_tmp);
 	rd_lastcode[rd_lencode] = '\0';
 
 	/*
@@ -498,8 +497,7 @@ true_receive(
 				refclock_report(peer, CEVNT_BADTIME);
 				return;
 			}
-			setlfpuint(off, sec);
-			setlfpfrac(off, 0);
+			off = lfpinut(sec, 0);
 #endif
 
 			pp->usec = true_sample720();
@@ -518,7 +516,7 @@ true_receive(
 			/*
 			 * Create a true offset for feeding to pps_sample()
 			 */
-			L_SUB(&off, &pp->lastrec);
+			off -= pp->lastrec;
 
 			pps_sample(peer, &off);
 #endif
@@ -582,10 +580,12 @@ true_send(
 
 	pp = peer->procptr;
 	if (!(pp->sloppyclockflag & CLK_FLAG1)) {
-		int len = strlen(cmd);
+                ssize_t ret;
+		size_t len = strlen(cmd);
 
 		true_debug(peer, "Send '%s'\n", cmd);
-		if (write(pp->io.fd, cmd, (unsigned)len) != len)
+		ret = write(pp->io.fd, cmd, len);
+		if (ret < 0 || (size_t)ret != len)
 			refclock_report(peer, CEVNT_FAULT);
 		else
 			pp->polls++;
