@@ -7,7 +7,7 @@
  * data.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "ntp_fp.h"
 #include "timespecops.h"
@@ -20,29 +20,17 @@
 #include <setjmp.h>
 #include <stdbool.h>
 
-#ifdef STRUCT_NTPTIMEVAL_HAS_TIME_TV_NSEC
+#ifdef HAVE_STRUCT_NTPTIMEVAL_TIME_TV_NSEC
 #define tv_frac_sec tv_nsec
 #else
 #define tv_frac_sec tv_usec
 #endif
 
-/* microseconds per second */
-#define MICROSECONDS 1000000
-
 /*
  * Convert usec to a time stamp fraction.
  */
 # define TVUTOTSF(tvu)	\
-	(uint32_t)((((uint64_t)(tvu) << 32) + MICROSECONDS / 2) / MICROSECONDS)
-
-/*
- * Convert a struct timeval to a time stamp.
- */
-#define TVTOTS(tv, ts) \
-	do { \
-		setlfpuint(*ts, (u_long)(tv)->tv_sec);   \
-		setlfpfrac(*ts, TVUTOTSF((tv)->tv_usec)); \
-	} while (false)
+	(uint32_t)((((uint64_t)(tvu) << 32) + US_PER_S / 2) / US_PER_S)
 
 #define NS_PER_MS_FLOAT	1000.0
 
@@ -58,7 +46,7 @@ int ntp_gettime(struct ntptimeval *ntv)
 	ntv->time = tntx.time;
 	ntv->maxerror = tntx.maxerror;
 	ntv->esterror = tntx.esterror;
-#if defined(STRUCT_NTPTIMEVAL_HAS_TAI)
+#if defined(HAVE_STRUCT_NTPTIMEVAL_TAI)
 	ntv->tai = tntx.tai;
 #endif
 	return result;
@@ -75,8 +63,6 @@ int ntp_gettime(struct ntptimeval *ntv)
 \11PPSSIGNAL\12PPSJITTER\13PPSWANDER\14PPSERROR\15CLOCKERR\
 \16NANO\17MODE\20CLK"
 
-#define SCALE_FREQ 65536		/* frequency scale */
-
 /*
  * These constants are used to round the time stamps computed from
  * a struct timeval to the microsecond (more or less).  This keeps
@@ -164,7 +150,7 @@ main(
 
 		case 'f':
 			ntx.modes |= MOD_FREQUENCY;
-			ntx.freq = (long)(atof(ntp_optarg) * SCALE_FREQ);
+			ntx.freq = (long)FP_SCALE(atof(ntp_optarg));
 			break;
 
 		case 'j':
@@ -338,11 +324,10 @@ main(
 #endif
 		tv.tv_sec = ntv.time.tv_sec;
 		tv.tv_usec = ntv.time.tv_frac_sec;
-		TVTOTS(&tv, &ts);
-		setlfpuint(ts, lfpuint(ts) + JAN_1970);
+		ts = tspec_stamp_to_lfp(tval_to_tspec(tv));
 		setlfpfrac(ts, lfpfrac(ts) + ts_roundbit);
 		setlfpfrac(ts, lfpfrac(ts) & ts_mask);
-		printf(json ? jfmt2 : ofmt2,  json ? rfc3339date(&ts) : prettydate(&ts), fdigits, (int)time_frac);
+		printf(json ? jfmt2 : ofmt2,  json ? rfc3339date(ts) : prettydate(ts), fdigits, (int)time_frac);
 		printf(json ? jfmt3 : ofmt3,  (u_long)ntv.maxerror, (u_long)ntv.esterror);
 		if (rawtime)
 			printf(json ? jfmt4 : ofmt4,
@@ -351,11 +336,11 @@ main(
 			       (int)time_frac,
 
 			       ctime_r((time_t *)&ntv.time.tv_sec, ascbuf));
-#if defined(STRUCT_NTPTIMEVAL_HAS_TAI)
+#if defined(HAVE_STRUCT_NTPTIMEVAL_TAI)
 		printf(json ? jfmt5 : ofmt5, (long)ntv.tai);
 #else
 		fputs(json ? jfmt6 : ofmt6, stdout);
-#endif /* STRUCT_NTPTIMEVAL_HAS_TAI */
+#endif /* HAVE_STRUCT_NTPTIMEVAL_TAI */
 	}
 	status = ntp_adjtime_ns(&ntx);
 	if (status < 0) {
@@ -391,14 +376,14 @@ main(
 		       snprintb(sizeof(binbuf), binbuf, ntx.modes, TIMEX_MOD_BITS));
 		ftemp = (double)ntx.offset/NS_PER_MS_FLOAT;
 		printf(json ? jfmt9 : ofmt9, ftemp);
-		ftemp = (double)ntx.freq / SCALE_FREQ;
+		ftemp = FP_UNSCALE(ntx.freq);
 		printf(json ? jfmt10 : ofmt10, ftemp, 1 << ntx.shift);
 		printf(json ? jfmt11 : ofmt11,
 		     (u_long)ntx.maxerror, (u_long)ntx.esterror);
 		printf(json ? jfmt12 : ofmt12,
 		       snprintb(sizeof(binbuf), binbuf,
 			       (u_int)ntx.status, TIMEX_STA_BITS));
-		ftemp = (double)ntx.tolerance / SCALE_FREQ;
+		ftemp = FP_UNSCALE(ntx.tolerance);
 		/*
 		 * Before the introduction of ntp_adjtime_ns() the
 		 * ntptime code divided this by 1000 when the STA_NANO
@@ -410,8 +395,8 @@ main(
 		printf(json ? jfmt13 : ofmt13,
 			(u_long)ntx.constant, gtemp, ftemp);
 		if (ntx.shift != 0) {
-			ftemp = (double)ntx.ppsfreq / SCALE_FREQ;
-			gtemp = (double)ntx.stabil / SCALE_FREQ;
+		  ftemp = FP_UNSCALE(ntx.ppsfreq);
+		  gtemp = FP_UNSCALE(ntx.stabil);
 			htemp = (double)ntx.jitter/NS_PER_MS_FLOAT;
 			printf(json ? jfmt14 : ofmt14,
 			    ftemp, gtemp, htemp);
